@@ -222,17 +222,27 @@ class Assets(WMLResource):
                         attachment_id = attachment_details["attachment_id"]
                         attachment_url = attachment_details["url1"]
                         #Step3: Put content to attachment
-                        with open(file_path, 'rb') as _file:
-                            if not self._ICP:
-                                    put_response = requests.put(
-                                        attachment_url,
-                                        data=_file
-                                    )
-                            else:
-                                    put_response = requests.put(
-                                        self._wml_credentials['url'] + attachment_url,
-                                        files={'file': (name, _file, 'file')}
-                                    )
+                        try:
+                            with open(file_path, 'rb') as _file:
+                                if not self._ICP:
+                                        put_response = requests.put(
+                                            attachment_url,
+                                            data=_file
+                                        )
+                                else:
+                                        put_response = requests.put(
+                                            self._wml_credentials['url'] + attachment_url,
+                                            files={'file': (name, _file, 'file')}
+                                        )
+                        except Exception as e:
+                            deletion_response = requests.delete(
+                                self._client.service_instance._href_definitions.get_data_asset_href(asset_id),
+                                params=self._client._params(),
+                                headers=self._client._get_headers()
+                            )
+                            print(deletion_response.status_code)
+                            raise WMLClientError(Messages.get_message(message_id="failed_while_creating_a_data_asset"), e)
+
                         if put_response.status_code == 201 or put_response.status_code == 200:
                             # Step4: Complete attachment
 
