@@ -38,10 +38,13 @@ from ibm_watson_machine_learning.volumes import Volume
 from ibm_watson_machine_learning.export_assets import Export
 from ibm_watson_machine_learning.import_assets import Import
 
+from ibm_watson_machine_learning.task_credentials import TaskCredentials
+
 import copy
 import os
 
 
+
 '''
 .. module:: APIClient
    :platform: Unix, Windows
@@ -75,6 +78,7 @@ class APIClient:
         self.ICP_40 = False # Use it for any 4.0 specific functionalities
         self.ICP_45 = False # Use it for any 4.5 specific functionalities
         self.ICP_46 = False # Use it for any 4.6 specific functionalities
+        self.ICP_47 = False # Use it for any 4.7 specific functionalities
         self.CLOUD_BETA_FLOW = False
         self._iam_id = None
         self._spec_ids_per_state = {}
@@ -131,7 +135,7 @@ class APIClient:
         self.wml_token = None
         self.__wml_local_supported_version_list = ['1.0', '1.1',
                                                    '2.0', '2.0.1', '2.0.2', '2.5.0',
-                                                   '3.0.0', '3.0.1', '3.5', '4.0', '4.5', '4.6']
+                                                   '3.0.0', '3.0.1', '3.5', '4.0', '4.5', '4.6', '4.7']
         self.__wsd_supported_version_list = ['1.0', '1.1', '2.0']
         self.__predefined_instance_type_list = ['icp', 'openshift', 'wml_local', 'wsd_local']
         os.environ['WSD_PLATFORM'] = 'False'
@@ -172,7 +176,7 @@ class APIClient:
                 if 'version' not in wml_credentials:
                     raise WMLClientError(Messages.get_message(self.__wml_local_supported_version_list, message_id="version_not_provided"))
 
-                if 'version' in wml_credentials.keys() and (wml_credentials[u'version'].lower() in ['3.5', '4.0', '4.5', '4.6', '1.1', '2.0']):
+                if 'version' in wml_credentials.keys() and (wml_credentials[u'version'].lower() in ['3.5', '4.0', '4.5', '4.6', '4.7', '1.1', '2.0']):
                     self.CAMS = True
                     os.environ["DEPLOYMENT_PRIVATE"] = "icp4d"
                     if 'wml_local' == wml_credentials[u'instance_id'].lower() and \
@@ -187,11 +191,12 @@ class APIClient:
                         self.ICP_PLATFORM_SPACES = True
                         self.ICP_35 = True
 
-                    if wml_credentials[u'version'].lower() in ['4.0', '4.5', '4.6']:
+                    if wml_credentials[u'version'].lower() in ['4.0', '4.5', '4.6', '4.7']:
                         self.ICP_PLATFORM_SPACES = True
                         self.ICP_40 = wml_credentials[u'version'].lower() == '4.0'
                         self.ICP_45 = wml_credentials[u'version'].lower() == '4.5'
                         self.ICP_46 = wml_credentials[u'version'].lower() == '4.6'
+                        self.ICP_47 = wml_credentials[u'version'].lower() == '4.7'
                         if 'bedrock_url' not in wml_credentials:
                             self.wml_credentials['bedrock_url'] = '.'.join(['https://cp-console'] + wml_credentials['url'].split('.')[1:])
                             self._is_bedrock_url_autogenerated = True
@@ -366,6 +371,7 @@ class APIClient:
                 from ibm_watson_machine_learning.migration_v4ga_cloud import Migrationv4GACloud
                 self.v4ga_cloud_migration = Migrationv4GACloud(self)
                 self.factsheets = Factsheets(self)
+                self.task_credentials = TaskCredentials(self)
 
             self.remote_training_systems = RemoteTrainingSystem(self)
 
