@@ -317,8 +317,13 @@ class Connections(WMLResource):
         return WMLResource._get_required_element_from_dict(connection_details, u'connection_details',
                                                            [u'metadata', u'id'])
 
-    def list_datasource_types(self):
+    def list_datasource_types(self, return_as_df=True):
         """Print stored datasource types assets in a table format.
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed datasource types or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
@@ -341,11 +346,19 @@ class Connections(WMLResource):
             (m[u'entity'][u'name'], m[u'metadata'][u'asset_id'], m[u'entity'][u'type'], m['entity']['status']) for
             m in datasource_details]
 
-        self._list(space_values, [u'NAME', u'DATASOURCE_ID', u'TYPE', u'STATUS'], None, None)
+        table = self._list(space_values, [u'NAME', u'DATASOURCE_ID', u'TYPE', u'STATUS'], None, None)
+        if return_as_df:
+            return table
 
-    def list(self):
+    def list(self, return_as_df=True):
         """Print all stored connections in a table format.
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed connections or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
         **Example**
 
         .. code-block:: python
@@ -359,11 +372,19 @@ class Connections(WMLResource):
              m['entity']['datasource_type']) for
             m in datasource_details['resources']]
 
-        self._list(space_values, [u'NAME', u'ID', u'CREATED', 'DATASOURCE_TYPE_ID'], None, None)
+        list_table = self._list(space_values, [u'NAME', u'ID', u'CREATED', 'DATASOURCE_TYPE_ID'], None, None)
+        if return_as_df:
+            return list_table
 
-    def list_uploaded_db_drivers(self):
+    def list_uploaded_db_drivers(self, return_as_df=True):
         """Print uploaded db driver jars in table a format. Supported for IBM Cloud Pak for Data only.
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed uploaded db drivers or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
         **Example**
 
         .. code-block:: python
@@ -377,7 +398,7 @@ class Connections(WMLResource):
         try:
             if not self.get_uploaded_db_drivers():
                 raise Exception('List empty for new api')
-            self._list_uploaded_db_drivers_new_api()
+            table = self._list_uploaded_db_drivers_new_api()
         except:
             response = requests.get(
                 self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + 'dbdrivers',
@@ -386,7 +407,9 @@ class Connections(WMLResource):
             )
             jars = [[el['path'].split('/')[-1]] for el in response.json()['resources']]
 
-            self._list(jars, [u'NAME'], None, None)
+            table = self._list(jars, [u'NAME'], None, None)
+        if return_as_df:
+            return table
 
     def get_uploaded_db_drivers(self): # TODO not yet documented
         # """
@@ -428,7 +451,7 @@ class Connections(WMLResource):
 
         """
         jars = [[name] for name in self.get_uploaded_db_drivers()]
-        self._list(jars, [u'NAME'], None, None)
+        return self._list(jars, [u'NAME'], None, None)
 
     def get_datasource_type_uid_by_name(self, name):
         """Get stored datasource types id for the given datasource type name.
