@@ -600,9 +600,9 @@ class BaseDeployment(ABC):
 
             project_asset_id = self._source_workspace.wml_client.repository.get_model_id(published_model_details)
 
-            asset_id = self._source_workspace.wml_client.repository.promote_model(model_id=project_asset_id,
-                                                                                  source_project_id=self._source_workspace.project_id,
-                                                                                  target_space_id=self._target_workspace.space_id)
+            asset_id = self._source_workspace.wml_client.spaces.promote(asset_id=project_asset_id,
+                                                                        source_project_id=self._source_workspace.project_id,
+                                                                        target_space_id=self._target_workspace.space_id)
 
         else:
             published_model_details = self._target_workspace.wml_client.repository.store_model(
