@@ -771,7 +771,7 @@ class Deployments(WMLResource):
         details = self.get_details(virtual_deployment_uid)
         download_url = self.get_download_url(details)
         if any([self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40, self._client.ICP_45,
-                self._client.ICP_46]):
+                self._client.ICP_46, self._client.ICP_47]):
             download_url = download_url + "&version=" + self._client.version_param
             params = None
         response = requests.get(
@@ -794,12 +794,18 @@ class Deployments(WMLResource):
         else:
             raise WMLClientError(u'Unable to download deployment content: ' + response.text)
 
-    def list(self, limit=None):
+    def list(self, limit=None, return_as_df=True):
         """Print deployments in a table format. If limit is set to None there will be only first 50 records shown.
 
         :param limit:  limit number of fetched records
         :type limit: int, optional
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed deployments or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
         **Example**
 
         .. code-block:: python
@@ -868,18 +874,28 @@ class Deployments(WMLResource):
             index = index + 1
 
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
-            self._list(values, [u'GUID', u'NAME', u'STATE', u'CREATED', u'ARTIFACT_TYPE'], limit, 50)
+            table = self._list(values, [u'GUID', u'NAME', u'STATE', u'CREATED', u'ARTIFACT_TYPE'], limit, 50)
         else:
-            self._list(values, ['GUID', 'NAME', 'STATE', 'CREATED', 'ARTIFACT_TYPE', 'SPEC_STATE', 'SPEC_REPLACEMENT'],
-                       limit, 50)
+            table = self._list(values,
+                               ['GUID', 'NAME', 'STATE', 'CREATED', 'ARTIFACT_TYPE', 'SPEC_STATE', 'SPEC_REPLACEMENT'],
+                               limit, 50)
 
-    def list_jobs(self, limit=None):
+        if return_as_df:
+            return table
+
+    def list_jobs(self, limit=None,  return_as_df=True):
         """Print the async deployment jobs in a table format.
         If limit is set to None there will be only first 50 records shown.
 
         :param limit:  limit number of fetched records
         :type limit: int, optional
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed deployment jobs or None
+        :rtype: pandas.DataFrame or None if return_as_df is False
+
         .. note::
 
             This method list only async deployment jobs created for WML deployment.
@@ -917,7 +933,9 @@ class Deployments(WMLResource):
 
             index = index + 1
 
-        self._list(values, ['JOB-UID', 'STATE', 'CREATED', 'DEPLOYMENT-ID'], limit, 50)
+        table = self._list(values, ['JOB-UID', 'STATE', 'CREATED', 'DEPLOYMENT-ID'], limit, 50)
+        if return_as_df:
+            return table
 
     def _get_deployable_asset_type(self, details):
         url = details[u'entity'][u'asset']['id']
