@@ -159,7 +159,7 @@ class AutoAI(BaseExperiment):
                   scoring: 'Metrics' = None,
                   desc: str = None,
                   test_size: float = None,  # deprecated
-                  holdout_size: float = 0.1,
+                  holdout_size: float = None,
                   max_number_of_estimators: int = None,
                   train_sample_rows_test_size: float = None,
                   include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms',
@@ -203,7 +203,10 @@ class AutoAI(BaseExperiment):
                   test_data_csv_separator: Union[List[str], str] = ',',
                   test_data_excel_sheet: str = None,
                   test_data_encoding: str = 'utf-8',
-                  confidence_level: float = 0.95,
+                  confidence_level: float = None,
+                  incremental_learning: bool = None,
+                  early_stop_enabled: bool = None,
+                  early_stop_window_size: int = None,
                   **kwargs) -> Union['RemoteAutoPipelines', 'LocalAutoPipelines']:
         """
         Initialize an AutoAi optimizer.
@@ -430,6 +433,14 @@ class AutoAI(BaseExperiment):
             is an anomaly or not, optional for timeseries anomaly prediction
         :type confidence_level: float, optional
 
+        :param incremental_learning: triggers incremental learning process for supported pipelines
+        :type incremental_learning: bool, optional
+
+        :param early_stop_enabled: enables early stop for incremental learning process
+        :type early_stop_enabled: bool, optional
+
+        :param early_stop_window_size: the number of iterations without score improvements before training stop
+        :type early_stop_window_size: int, optional
 
         :return: RemoteAutoPipelines or LocalAutoPipelines, depends on how you initialize the AutoAI object
         :rtype: RemoteAutoPipelines or LocalAutoPipelines
@@ -487,7 +498,7 @@ class AutoAI(BaseExperiment):
                 message="Support for excel sheet as number of the sheet (int) is deprecated! Please set excel sheet with name of the sheet.")
 
         if data_join_graph is not None:
-            if self._workspace.wml_client.ICP_46:
+            if self._workspace.wml_client.ICP_46 or self._workspace.wml_client.ICP_47:
                 raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cpd"))
             elif self._workspace.wml_client.ICP:
                 print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
@@ -516,7 +527,7 @@ class AutoAI(BaseExperiment):
             if feature_columns is None or prediction_column is not None or prediction_columns is not None:
                 raise TimeseriesAnomalyPredictionFeatureColumnsMissing()
             if scoring is not None and scoring not in (
-                    Metrics.F1_SCORE, Metrics.ACCURACY_SCORE, Metrics.BALANCED_ACCURACY, Metrics.PRECISION_SCORE,
+                    Metrics.F1_SCORE, Metrics.ROC_AUC_SCORE, Metrics.AVERAGE_PRECISION_SCORE, Metrics.PRECISION_SCORE,
                     Metrics.RECALL_SCORE):
                 raise TimeseriesAnomalyPredictionUnsupportedMetric(scoring)
         else:
@@ -535,7 +546,7 @@ class AutoAI(BaseExperiment):
                 include_only_estimators = daub_include_only_estimators
             daub_include_only_estimators = None
 
-        if train_sample_rows_test_size and self._workspace.wml_client.ICP_46:
+        if train_sample_rows_test_size and (self._workspace.wml_client.ICP_46 or self._workspace.wml_client.ICP_47):
             print('Note: Using `train_sample_rows_test_size` is deprecated.'
                   'Use either `sample_rows_limit` or `sample_percentage_limit` instead.')
             if not sample_rows_limit and not sample_percentage_limit:
@@ -719,6 +730,9 @@ class AutoAI(BaseExperiment):
                 test_data_excel_sheet=test_data_excel_sheet,
                 test_data_encoding=test_data_encoding,
                 confidence_level=confidence_level,
+                incremental_learning=incremental_learning,
+                early_stop_enabled=early_stop_enabled,
+                early_stop_window_size=early_stop_window_size,
                 **reduced_kwargs
             )
             optimizer._workspace = self._workspace
