@@ -107,12 +107,14 @@ class WMLEngine(BaseEngine):
                             'encoding': self._auto_pipelines_parameters.get('encoding'),
                             'drop_duplicates': self._auto_pipelines_parameters.get('drop_duplicates'),
                             'outliers_columns': self._auto_pipelines_parameters.get('outliers_columns'),
+                            'incremental_learning': self._auto_pipelines_parameters.get('incremental_learning'),
+                            'enable_early_stop': self._auto_pipelines_parameters.get('early_stop_enabled'),
+                            'early_stop_window_size': self._auto_pipelines_parameters.get('early_stop_window_size'),
                             'optimization': {
                                 'learning_type': self._get_learning_type(),
                                 'cognito_transform_names':
                                     self._auto_pipelines_parameters.get('cognito_transform_names'),
                                 'run_cognito_flag': True,
-                                'holdout_param': self._auto_pipelines_parameters.get('holdout_size'),
                             }
                         },
                         'runtime_ref': 'autoai',
@@ -132,6 +134,11 @@ class WMLEngine(BaseEngine):
             }
         }
 
+        if self._auto_pipelines_parameters.get('holdout_size') is not None:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'holdout_param'] = self._auto_pipelines_parameters.get('holdout_size')
+
         if self._auto_pipelines_parameters.get('max_num_daub_ensembles') is not None:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                 'pipelines'][0]['nodes'][0]['parameters']['optimization'][
@@ -182,7 +189,7 @@ class WMLEngine(BaseEngine):
         # end of section
 
         # pass fairness info for Cloud or CP4D 4.5
-        if self._wml_client.CLOUD_PLATFORM_SPACES or self._wml_client.ICP_45 or self._wml_client.ICP_46:
+        if self._wml_client.CLOUD_PLATFORM_SPACES or self._wml_client.ICP_45 or self._wml_client.ICP_46 or self._wml_client.ICP_47:
             if self._auto_pipelines_parameters.get('fairness_info') is not None:
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
@@ -291,9 +298,10 @@ class WMLEngine(BaseEngine):
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                     'timestamp_column'] = self._auto_pipelines_parameters['timestamp_column_name']
-            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
-                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
-                'max_num_pipelines'] = self._auto_pipelines_parameters.get('max_num_daub_ensembles')
+            if self._auto_pipelines_parameters.get('max_num_daub_ensembles') is not None:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'max_num_pipelines'] = self._auto_pipelines_parameters.get('max_num_daub_ensembles')
             if self._auto_pipelines_parameters['pipeline_types']:
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
@@ -302,9 +310,10 @@ class WMLEngine(BaseEngine):
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                     'evaluation_metric'] = self._auto_pipelines_parameters['scoring']
-            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
-                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
-                'confidence_level'] = self._auto_pipelines_parameters.get('confidence_level', 0.95)
+            if self._auto_pipelines_parameters.get('confidence_level') is not None:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'confidence_level'] = self._auto_pipelines_parameters.get('confidence_level')
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                 'pipelines'][0]['nodes'][0]['parameters'][
                 'compute_pipeline_notebooks_flag'] = self._auto_pipelines_parameters.get('notebooks', False)
@@ -556,7 +565,7 @@ class WMLEngine(BaseEngine):
                     'runtimes'][0]['version'] = self._auto_pipelines_parameters['obm_pod_version']
 
             else:
-                if self._wml_client.ICP_45 or self._wml_client.ICP_46:
+                if self._wml_client.ICP_45 or self._wml_client.ICP_46 or self._wml_client.ICP_47:
                     template_id = 'spark-3.2-automl-cp4d-template'
                 elif not self._wml_client.ICP_35:
                     template_id = 'spark-3.0.0-automl-cp4d-template'
@@ -855,9 +864,17 @@ class WMLEngine(BaseEngine):
     #################################################################################
     #   WML Auto_AI Trained Pipelines Part / AutoPipelineOptimizer Pipelines Part   #
     #################################################################################
-    def summary(self) -> 'DataFrame':
+    def summary(self, scoring: str = None, sort_by_holdout_score: bool = True) -> 'DataFrame':
         """Prints AutoPipelineOptimizer Pipelines details (autoai trained pipelines).
 
+        :param scoring: scoring metric which user wants to use to sort pipelines by,
+            when not provided use optimized one
+        :type scoring: string, optional
+
+        :param sort_by_holdout_score: indicates if we want to sort pipelines by holdout metric or by training one,
+            by default use holdout metric
+        :type sort_by_holdout_score: bool, optional
+
         :return: DataFrame with computed pipelines and ML metrics
         :rtype: pandas.DataFrame
         """
@@ -865,7 +882,18 @@ class WMLEngine(BaseEngine):
             raise FitNeeded(reason="To list computed pipelines, first schedule a fit job by using the fit() method.")
 
         details = self._wml_client.training.get_details(training_uid=self._current_run_id, _internal=True)
-        return create_summary(details=details, scoring=self._auto_pipelines_parameters['scoring'])
+        optimized_scoring = self._auto_pipelines_parameters.get('scoring', None)
+
+        if scoring is None:
+            scoring = optimized_scoring
+
+        summary = create_summary(details=details, scoring=scoring, sort_by_holdout_score=sort_by_holdout_score)
+
+        if isinstance(optimized_scoring, str) and optimized_scoring.startswith('neg_'):
+            optimized_scoring = optimized_scoring[4:]
+
+        return summary.rename({
+            f"training_{optimized_scoring}": f"training_{optimized_scoring}_(optimized)"}, axis='columns')
 
     def get_pipeline_details(self, pipeline_name: str = None) -> dict:
         """Fetch specific pipeline details, eg. steps etc.
@@ -904,9 +932,19 @@ class WMLEngine(BaseEngine):
                 if 'timeseries' not in pipeline['context']:
                     pipeline_parameters['ml_metrics'] = self._get_metrics(pipeline)
                 else:
-                    if not 'ts_metrics' in pipeline_parameters:
-                        pipeline_parameters['ts_metrics'] = {}
-                    pipeline_parameters['ts_metrics'].update(self._get_metrics(pipeline))
+                    if self._auto_pipelines_parameters['prediction_type'] == PredictionType.TIMESERIES_ANOMALY_PREDICTION:
+                        for pipeline_metrics in run_params['entity']['status'].get('metrics', [])[::-1]:
+                            pipeline_phase = pipeline_metrics['context'].get('phase')
+                            if pipeline_metrics['context']['intermediate_model']['name'].split('P')[-1] ==pipeline_name.split('_')[-1] and pipeline_phase == "after_holdout_execution":
+                                pipeline_parameters['tsad_metrics'] = self._get_metrics(pipeline_metrics)
+                                break
+                    else:
+                        if not 'ts_metrics' in pipeline_parameters:
+                            pipeline_parameters['ts_metrics'] = {}
+                        pipeline_parameters['ts_metrics'].update(self._get_metrics(pipeline))
+
+                if 'incremental_training' in pipeline['context']:
+                    pipeline_parameters['learning_curve'] = self._get_learning_curve(pipeline, run_params)
 
                 if (self._auto_pipelines_parameters['prediction_type'] == 'binary'
                         or (self._auto_pipelines_parameters['prediction_type'] == 'classification'
@@ -993,12 +1031,25 @@ class WMLEngine(BaseEngine):
             path = details[f'{property_name}_location']
             conn = DataConnection._from_dict(results_reference)
             conn._wml_client = self._wml_client
-            return conn._download_json_file(path)
+            if path.endswith('.csv'):
+                return conn._download_csv_file(path)
+            else:
+                return conn._download_json_file(path)
         elif property_name in details:  # TODO probably should be removed in future
             return details[property_name]
         else:
             return default_value
 
+    def _get_learning_curve(self, pipeline_details: Dict, run_params: Dict) -> 'DataFrame':
+        """Retrieve learning curve data from file."""
+
+        data = self._get_data_from_property_or_file('measures',
+                                                    pipeline_details['context'].get('incremental_training', {}),
+                                                    run_params['entity']['results_reference'],
+                                                    [{}, {}])
+
+        return data
+
     def _get_confusion_matrix(self, pipeline_details: Dict, run_params: Dict) -> 'DataFrame':
         """Retrieve confusion matrix data from particular pipeline details or from file. (Binary)"""
         data = self._get_data_from_property_or_file('confusion_matrix',
@@ -1007,10 +1058,11 @@ class WMLEngine(BaseEngine):
                                                          [{}, {}])
         columns = [name for name in data[0].keys()]
         values = [[value for value in item.values()] for item in data]
-
         confusion_matrix_data = DataFrame(data=values, columns=columns)
-        confusion_matrix_data.index = confusion_matrix_data['true_class']
-        confusion_matrix_data.drop(['true_class'], axis=1, inplace=True)
+
+        if 'true_class' in confusion_matrix_data.columns:
+            confusion_matrix_data.index = confusion_matrix_data['true_class']
+            confusion_matrix_data.drop(['true_class'], axis=1, inplace=True)
 
         return confusion_matrix_data
 
@@ -1035,8 +1087,12 @@ class WMLEngine(BaseEngine):
                                                          [])
 
         true_classes = [item['true_class'] for item in data]
-        values = [data[0]['fpr'], data[1]['fpr'], data[0]['thresholds'], data[1]['thresholds'], data[0]['tpr'],
-                  data[1]['tpr']]
+
+        if len(data) > 0:
+            values = [data[0]['fpr'], data[1]['fpr'], data[0]['thresholds'], data[1]['thresholds'], data[0]['tpr'],
+                      data[1]['tpr']]
+        else:
+            values = []
 
         index = MultiIndex.from_product([['fpr', 'thresholds', 'tpr'], true_classes],
                                         names=['measurement types', 'true_class'])
