@@ -119,7 +119,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  engine: 'WMLEngine',
                  scoring: 'Metrics' = None,
                  desc: str = None,
-                 holdout_size: float = 0.1,
+                 holdout_size: float = None,
                  max_num_daub_ensembles: int = None,
                  t_shirt_size: 'TShirtSize' = TShirtSize.M,
                  train_sample_rows_test_size: float = None,
@@ -166,7 +166,10 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  supporting_features_at_forecast: bool = None,
                  categorical_columns: list = None,
                  numerical_columns: list = None,
-                 confidence_level: float = 0.95,
+                 confidence_level: float = None,
+                 incremental_learning: bool = None,
+                 early_stop_enabled: bool = None,
+                 early_stop_window_size: int = None,
                  **kwargs):
 
         if data_join_graph is not None:
@@ -229,8 +232,11 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'pipeline_types': pipeline_types,
             'supporting_features_at_forecast': supporting_features_at_forecast,
             'numerical_columns': numerical_columns,
-            'categorical_columns':categorical_columns,
+            'categorical_columns': categorical_columns,
             'confidence_level': confidence_level,
+            'incremental_learning': incremental_learning,
+            'early_stop_enabled': early_stop_enabled,
+            'early_stop_window_size': early_stop_window_size
         }
 
         if fairness_info:
@@ -352,7 +358,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                 background_mode=False)
         """
         if self.params.get('data_join_graph'):
-            if self._workspace.wml_client.ICP_46:
+            if self._workspace.wml_client.ICP_46 or self._workspace.wml_client.ICP_47:
                 raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cpd"))
             elif self._workspace.wml_client.ICP:
                 print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
@@ -588,7 +594,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             remote_optimizer.get_run_details()
         """
         if not _internal and self.params.get('data_join_graph'):
-            if self._workspace.wml_client.ICP_46:
+            if self._workspace.wml_client.ICP_46 or self._workspace.wml_client.ICP_47:
                 raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cpd"))
             elif self._workspace.wml_client.ICP:
                 print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
@@ -604,9 +610,17 @@ class RemoteAutoPipelines(BaseAutoPipelines):
     #################################
     #   Pipeline models operations  #
     #################################
-    def summary(self) -> 'DataFrame':
+    def summary(self, scoring: str = None, sort_by_holdout_score: bool = True) -> 'DataFrame':
         """Print AutoPipelineOptimizer Pipelines details (autoai trained pipelines).
 
+        :param scoring: scoring metric which user wants to use to sort pipelines by,
+            when not provided use optimized one
+        :type scoring: string, optional
+
+        :param sort_by_holdout_score: indicates if we want to sort pipelines by holdout metric or by training one,
+            by default use holdout metric
+        :type sort_by_holdout_score: bool, optional
+
         :return: computed pipelines and ML metrics
         :rtype: pandas.DataFrame
 
@@ -628,7 +642,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             # Pipeline_1                                 0.358124  ...     0.449057
             # Pipeline_2                                 0.358124  ...     0.449057
         """
-        return self._engine.summary()
+        return self._engine.summary(scoring, sort_by_holdout_score)
 
     def get_pipeline_details(self, pipeline_name: str = None) -> dict:
         """Fetch specific pipeline details, eg. steps etc.
