@@ -287,8 +287,8 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 'encoding': encoding,
                 'pipeline_types': tsad_parameters.get('pipelines'),
                 'retrain_on_holdout': tsad_parameters.get('retrain_on_holdout', True),
-                'scoring': tsad_parameters.get('evaluation_metric', 'f1'),
-                'confidence_level': tsad_parameters.get('confidence_level', 0.95),
+                'scoring': tsad_parameters.get('evaluation_metric', 'average_precision'),
+                # 'confidence_level': tsad_parameters.get('confidence_level', 0.95),
             }
         else:
             params = {
