@@ -291,13 +291,19 @@ class Experiments(WMLResource):
 
         return self._handle_response(204, u'experiment deletion', response, False)
 
-    def list(self, limit=None):
+    def list(self, limit=None, return_as_df=True):
         """Print stored experiments in a table format.
         If limit is set to None there will be only first 50 records shown.
 
         :param limit: limit number of fetched records
         :type limit: int, optional
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed experiments or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
         **Example**
 
         .. code-block:: python
@@ -317,7 +323,9 @@ class Experiments(WMLResource):
             experiment_values = [(m[u'metadata'][u'id'], m[u'entity'][u'name'], m[u'metadata'][u'created_at']) for m in
                                  experiment_resources]
 
-        self._list(experiment_values, header_list, limit, _DEFAULT_LIST_LENGTH)
+        table = self._list(experiment_values, header_list, limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     def create_revision(self, experiment_id):
         """Create a new experiment revision.
@@ -378,7 +386,7 @@ class Experiments(WMLResource):
             return self._get_with_or_without_limit(url, limit=None, op_name="experiments",
                                                    summary=None, pre_defined=None, revision=rev_uid)
 
-    def list_revisions(self, experiment_uid, limit=None):
+    def list_revisions(self, experiment_uid, limit=None, return_as_df=True):
         """Print all revision for the given experiment uid in a table format.
 
         :param experiment_uid: Unique id of stored experiment
@@ -387,6 +395,12 @@ class Experiments(WMLResource):
         :param limit: limit number of fetched records
         :type limit: int, optional
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed revisions or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
         **Example**
 
         .. code-block:: python
@@ -409,7 +423,9 @@ class Experiments(WMLResource):
                 (m[u'metadata'][u'rev'], m[u'metadata'][u'name'], m[u'metadata'][u'created_at']) for m in
                 experiment_resources]
 
-            self._list(experiment_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+            table = self._list(experiment_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+            if return_as_df:
+                return table
 
     def clone(self, experiment_uid, space_id=None, action="copy", rev_id=None):
         """Create a new experiment identical with the given experiment either in the same space or in a new space.
