@@ -323,7 +323,7 @@ class Export(WMLResource):
         else:
             return self._get_artifact_details(href, export_id, limit, 'export job', query_params=params)
     
-    def list(self, space_id=None, project_id=None, limit=None):
+    def list(self, space_id=None, project_id=None, limit=None, return_as_df=True):
         """Print export jobs in a table format. If limit is set to None there will be only first 50 records shown.
 
         :param space_id: space identifier
@@ -332,6 +332,11 @@ class Export(WMLResource):
         :type project_id: str, optional
         :param limit: limit number of fetched records
         :type limit: int, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed connections or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
@@ -359,7 +364,9 @@ class Export(WMLResource):
                    m[u'metadata'][u'created_at'],
                    m[u'entity'][u'status'][u'state']) for m in resources]
 
-        self._list(values, [u'ID', u'NAME', u'CREATED', u'STATUS'], limit, _DEFAULT_LIST_LENGTH)
+        table = self._list(values, [u'ID', u'NAME', u'CREATED', u'STATUS'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     @staticmethod
     def get_id(export_details):
