@@ -658,12 +658,18 @@ class Functions(WMLResource):
                 # Cloud Convergence
                 return "/ml/v4/functions/{}".format(function_details[u'metadata'][u'id'])
 
-    def list(self, limit=None):
+    def list(self, limit=None, return_as_df=True):
         """Print stored functions in a table format. If limit is set to None there will be only first 50 records shown.
 
         :param limit: limit number of fetched records
         :type limit: int, optional
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed functions or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
         **Example**
 
         .. code-block:: python
@@ -671,7 +677,7 @@ class Functions(WMLResource):
             client._functions.list()
         """
         ##For CP4D, check if either spce or project ID is set
-
+        table = None
         if self._client.WSD:
             Functions._wsd_list_assets(self, "wml_function", limit)
         else:
@@ -696,13 +702,16 @@ class Functions(WMLResource):
                                     get_spec_info(m['entity'].get('software_spec', {}).get('id'), 'replacement'))
                                    for m in function_resources]
 
-                self._list(function_values, ['GUID', 'NAME', 'CREATED', 'TYPE', 'SPEC_STATE', 'SPEC_REPLACEMENT'],
+                table = self._list(function_values, ['GUID', 'NAME', 'CREATED', 'TYPE', 'SPEC_STATE', 'SPEC_REPLACEMENT'],
                            limit, _DEFAULT_LIST_LENGTH)
             else:
                 function_values = [(m['metadata']['guid'], m['entity']['name'], m['metadata']['created_at'],
                                       m['entity']['type']) for m in function_resources]
 
-                self._list(function_values, ['GUID', 'NAME', 'CREATED', 'TYPE'], limit, _DEFAULT_LIST_LENGTH)
+                table = self._list(function_values, ['GUID', 'NAME', 'CREATED', 'TYPE'], limit, _DEFAULT_LIST_LENGTH)
+
+        if return_as_df:
+            return table
 
     def clone(self, function_uid, space_id=None, action="copy", rev_id=None):
         """Create a new function identical with the given function either in the same space or in a new space.
@@ -814,7 +823,7 @@ class Functions(WMLResource):
             return self._get_with_or_without_limit(url, limit=None, op_name="function",
                                                    summary=None, pre_defined=None, revision=rev_uid)
 
-    def list_revisions(self, function_uid, limit=None):
+    def list_revisions(self, function_uid, limit=None, return_as_df=True):
         """Print all revision for the given function uid in a table format.
 
         :param function_uid: Unique id of stored function
@@ -823,6 +832,12 @@ class Functions(WMLResource):
         :param limit: limit number of fetched records
         :type limit: int, optional
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed revisions or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
         **Example**
 
         .. code-block:: python
@@ -847,7 +862,7 @@ class Functions(WMLResource):
                     (m[u'metadata'][u'rev'], m[u'metadata'][u'name'], m[u'metadata'][u'created_at']) for m in
                     function_resources]
 
-                self._list(function_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+                table = self._list(function_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
             else:
                 function_resources = self._get_artifact_details(url + '/revisions',
                                                                 None,
@@ -861,7 +876,9 @@ class Functions(WMLResource):
                      m[u'metadata'][u'created_at']) for m in
                     function_resources]
 
-                self._list(function_values, [u'GUID', u'rev', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+                table = self._list(function_values, [u'GUID', u'rev', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     @staticmethod
     def _prepare_function_content(function):
