@@ -15,6 +15,8 @@ from abc import ABC, abstractmethod
 from typing import Union, Tuple, TYPE_CHECKING
 from warnings import warn
 
+import pandas as pd
+
 import ibm_watson_machine_learning._wrappers.requests as requests
 from pandas import concat, DataFrame, read_csv
 
@@ -121,6 +123,49 @@ class BaseDataConnection(ABC):
         else:
             raise Exception("OBM function called when not OBM scenario.")
 
+    def _download_csv_file(self, path) -> dict:
+        """Download csv file."""
+        df = pd.DataFrame()
+
+        if '//' in path:  # sometimes there is an additional slash, need to replace it
+            path = path.replace('//', '/')
+
+        if self.type == DataConnectionTypes.FS:
+            csv_url = self._wml_client.service_instance._href_definitions.get_wsd_model_attachment_href() + f"/auto_ml/{path.split('/auto_ml/')[-1]}"
+
+            with requests.get(csv_url, params=self._wml_client._params(), headers=self._wml_client._get_headers(),
+                              stream=True) as file_response:
+                if file_response.status_code != 200:
+                    raise ApiRequestFailure(u'Failure during {}.'.format("downloading json"), file_response)
+
+                downloaded_asset = file_response.content
+                df = pd.read_csv(io.BytesIO(downloaded_asset))
+                #json_content = json.loads(buffer.getvalue().decode('utf-8'))
+
+        elif self.type == DataConnectionTypes.CA or self.type == DataConnectionTypes.CN:
+            if self._check_if_connection_asset_is_s3():
+                cos_client = self._init_cos_client()
+
+                try:
+                    file = cos_client.Object(self.location.bucket, path).get()
+                    content = file["Body"].read()
+                    df = pd.read_csv(io.BytesIO(content))
+
+                except Exception as cos_access_exception:
+                    raise ConnectionError(
+                        f"Unable to access data object in cloud object storage with credentials supplied. "
+                        f"Error: {cos_access_exception}")
+
+            else:
+                raise NotImplementedError(f"Unsupported connection type: {self.type}. "
+                                          f"Datasource type is not supported. "
+                                          f"Supported type is: bluemixcloudobjectstorage")
+
+        else:
+            raise NotImplementedError(f"Unsupported connection type: {self.type}")
+
+        return df
+
     def _download_json_file(self, path) -> dict:
         """Download json file."""
         json_content = {}
