@@ -356,10 +356,22 @@ class DataConnection(BaseDataConnection):
                 )
 
             else:
-                data_connection: 'DataConnection' = cls(
-                    connection=NFSConnection(asset_id=_dict['connection']['asset_id']),
-                    location=NFSLocation(path=_dict['location']['path'])
-                )
+                if 'asset_id' in _dict['connection']:
+                    data_connection: 'DataConnection' = cls(
+                        connection=NFSConnection(asset_id=_dict['connection']['asset_id']),
+                        location=NFSLocation(path=_dict['location']['path'])
+                    )
+                else:
+                    if _dict['location'].get('file_name') is not None:
+                        data_connection: 'DataConnection' = cls(
+                            connection_asset_id=_dict['connection']['id'],
+                            location=NFSLocation(path=_dict['location']['file_name'])
+                        )
+                    else:
+                        data_connection: 'DataConnection' = cls(
+                            connection_asset_id=_dict['connection']['id'],
+                            location=NFSLocation(path=_dict['location']['path'])
+                        )
         elif _dict['type'] == DataConnectionTypes.CN:
             data_connection: 'DataConnection' = cls(
                 location=ContainerLocation(path=_dict['location']['path'])
@@ -446,11 +458,12 @@ class DataConnection(BaseDataConnection):
             )
 
             X_columns = self.auto_pipeline_params['feature_columns']
+            y_column = ['anomaly_label']
 
             X_train = DataFrame(X_train, columns=X_columns)
             X_holdout = DataFrame(X_holdout, columns=X_columns)
-            y_train = DataFrame(y_train, columns=X_columns)
-            y_holdout = DataFrame(y_holdout, columns=X_columns)
+            y_train = DataFrame(y_train, columns=y_column)
+            y_holdout = DataFrame(y_holdout, columns=y_column)
 
             return X_train, X_holdout, y_train, y_holdout
 
@@ -517,7 +530,7 @@ class DataConnection(BaseDataConnection):
                     y=dfy,
                     learning_type=self.auto_pipeline_params['prediction_type'],
                     fairness_info=self.auto_pipeline_params.get('fairness_info', None),
-                    test_size=self.auto_pipeline_params['holdout_size'],
+                    test_size=self.auto_pipeline_params.get('holdout_size') if self.auto_pipeline_params.get('holdout_size') is not None else 0.1,
                     return_only_holdout=False
                 )
 
@@ -632,7 +645,7 @@ class DataConnection(BaseDataConnection):
             use_flight = kwargs.get(
                 'use_flight',
                 bool((self._wml_client is not None or 'USER_ACCESS_TOKEN' in os.environ or 'RUNTIME_ENV_ACCESS_TOKEN_FILE' in os.environ) and (
-                        self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.ICP_46)))
+                        self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.ICP_46 or self._wml_client.ICP_47)))
         except:
             use_flight = False
 
@@ -983,7 +996,7 @@ class DataConnection(BaseDataConnection):
         use_flight = kwargs.get(
             'use_flight',
             bool((self._wml_client is not None or 'USER_ACCESS_TOKEN' in os.environ or 'RUNTIME_ENV_ACCESS_TOKEN_FILE' in os.environ) and (
-                    self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.ICP_46)))
+                    self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.ICP_46 or self._wml_client.ICP_47)))
 
         flight_parameters = kwargs.get('flight_parameters', {})
 
