@@ -448,7 +448,8 @@ class FlightConnection:
 
                 elif 'CDICO9999E' in str(e):
                     raise WrongLocationProperty(reason=str(e))
-                elif 'CDICO2027E' in str(e):
+                elif any(err_code in str(e)
+                         for err_code in ['CDICO2016E', 'CDICO2026E', 'CDICO2027E']):
                     retry = True
                     if count < 3:
                         logger.debug(f"Retry to get the endpoints of flight service at the ${count} time")
@@ -460,11 +461,12 @@ class FlightConnection:
                     raise e
             except pa.lib.ArrowInvalid as e:
                 logger.debug(f"Caught ArrowInvalid in get_endpoints: {str(e)}")
-                if 'No asset found with the id' in str(e):
+                if any(err_msg in str(e)
+                         for err_msg in ['No asset found with the id', 'Asset with ID']):
                     retry = True
                     if count < 3:
                         logger.debug(f"Retry to get the endpoints of flight service at the ${count} time")
-                        time.sleep(1)
+                        time.sleep(3)
                     else:
                         logger.debug(f"Reached the max retry times ${count}")
                         raise e
