@@ -164,6 +164,8 @@ DATAPLATFORM_URLS_MAP = {
 WKC_MODEL_REGISTER = u"{}/v1/aigov/model_inventory/models/{}/model_entry"
 WKC_MODEL_LIST_FROM_CATALOG = u"{}/v1/aigov/model_inventory/{}/model_entries"
 WKC_MODEL_LIST_ALL = u"{}/v1/aigov/model_inventory/model_entries"
+TASK_CREDENTIALS = u"{}/v1/task_credentials/{}"
+TASK_CREDENTIALS_ALL = u"{}/v1/task_credentials"
 
 def is_url(s):
     res = re.match('https?:\/\/.+', s)
@@ -526,6 +528,12 @@ class HrefDefinitions:
     def get_wkc_model_delete_href(self, asset_id) -> str:
         return WKC_MODEL_REGISTER.format(self._get_platform_url_if_exists(), asset_id)
 
+    def get_task_credentials_href(self, task_credentials_uid) -> str:
+        return TASK_CREDENTIALS.format(self._get_platform_url_if_exists(), task_credentials_uid)
+
+    def get_task_credentials_all_href(self) -> str:
+        return TASK_CREDENTIALS_ALL.format(self._get_platform_url_if_exists())
+
 
     # def get_envs_href(self):
     #     return DEPLOYMENT_ENVS_HREF_PATTERN.format(self._wml_credentials['url'])
