@@ -100,12 +100,18 @@ class HwSpec(WMLResource):
     #
     #     return hw_spec_details
 
-    def list(self, name=None):
+    def list(self, name=None, return_as_df=True):
         """Print hardware specifications in a table format.
 
         :param name: Unique id of the hardware spec
         :type name: str, optional
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed hardware specifications or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
         **Example**
 
         .. code-block:: python
@@ -129,7 +135,9 @@ class HwSpec(WMLResource):
         hw_spec_values = [
             (m[u'metadata'][u'name'], m[u'metadata'][u'asset_id'], m[u'metadata'][u'description']) for
             m in asset_details]
-        self._list(hw_spec_values, [u'NAME', u"ID", u'DESCRIPTION'], None, _DEFAULT_LIST_LENGTH)
+        table = self._list(hw_spec_values, [u'NAME', u"ID", u'DESCRIPTION'], None, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     @staticmethod
     def get_id(hw_spec_details):
