@@ -274,7 +274,7 @@ class Import(WMLResource):
         else:
             return self._get_artifact_details(href, import_id, limit, 'import job', query_params=params)
     
-    def list(self, space_id=None, project_id=None, limit=None):
+    def list(self, space_id=None, project_id=None, limit=None, return_as_df=True):
         """Print import jobs in a table format. If limit is set to None there will be only first 50 records shown.
 
         :param space_id: space identifier
@@ -283,6 +283,12 @@ class Import(WMLResource):
         :type project_id: str, optional
         :param limit: limit number of fetched records
         :type limit: int, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed assets or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
 
         **Example**
 
@@ -308,7 +314,9 @@ class Import(WMLResource):
                    m[u'metadata'][u'created_at'],
                    m[u'entity'][u'status'][u'state']) for m in resources]
 
-        self._list(values, [u'ID',  u'CREATED', u'STATUS'], limit, _DEFAULT_LIST_LENGTH)
+        table = self._list(values, [u'ID',  u'CREATED', u'STATUS'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     @staticmethod
     def get_id(import_details):
