@@ -342,7 +342,7 @@ class ServiceInstanceNewPlan:
         :return: newly created token is returned if no errors occurred
         :rtype: str
         """
-        if (self._client.ICP_40 or self._client.ICP_45 or self._client.ICP_46) and 'bedrock_url' in self._client.wml_credentials and 'password' in self._client.wml_credentials:
+        if (self._client.ICP_40 or self._client.ICP_45 or self._client.ICP_46 or self._client.ICP_47) and 'bedrock_url' in self._client.wml_credentials and 'password' in self._client.wml_credentials:
             try:
                 return self._get_cpd_token_from_request_new_auth_flow()
             except Exception as e1:
