@@ -2,21 +2,17 @@
 #  (C) Copyright IBM Corp. 2021- 2023.
 #  https://opensource.org/licenses/BSD-3-Clause
 #  -----------------------------------------------------------------------------------------
-
 from __future__ import print_function
 import sys
-import math
 import inspect
 import logging
-import operator
-import itertools
 import numpy as np
 from scipy import stats
+import scipy.stats.mstats as mstats
 from functools import partial
 from numcompress import compress
 from abc import ABC, abstractmethod
 from ddsketch.ddsketch import DDSketch
-from timeit import default_timer as time
 
 from sklearn.metrics import check_scoring
 from sklearn.model_selection import train_test_split
@@ -29,9 +25,9 @@ from sklearn.ensemble._hist_gradient_boosting.binning import _BinMapper
 from ibmfl.model.xgb_fl_model import XGBFLModel
 from ibmfl.util.xgboost.utils import is_classifier, _LOSSES
 from ibmfl.util.xgboost.hyperparams import init_parameters
+from ibmfl.message.message_type import MessageType
 
-from ibmfl.exceptions import HyperparamsException
-from ibmfl.exceptions import LocalTrainingException, ModelUpdateException
+from ibmfl.exceptions import LocalTrainingException
 from ibmfl.party.training.local_training_handler import LocalTrainingHandler
 
 logger = logging.getLogger(__name__)
@@ -48,24 +44,37 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
 
         :param model_update: ModelUpdate
         :type model_update: `ModelUpdate`
-        :return: `None`
+        :return: `bool`
         """
+        status = False
         try:
             # Check to see if worker's core model object has been initialized.
             if self.fl_model is None:
                 self.fl_model = XGBFLModel('XGBFLModel', self.hyperparams)
                 logger.info(
-                    'No model update was provided, initialized new FL model object.')
-
+                    'update_model: Initialized a new FL model object [party_id={}]'.format(self.party_id))
             # Update Model Object
             if model_update is not None:
-                self.fl_model.update_model(model_update)
-                logger.info('Local model updated.')
+                status = self.fl_model.update_model(model_update)
+                logger.info('update_model: Local model updated [party_id={}]'.format(self.party_id))
             else:
-                logger.info('No model update was provided.')
+                logger.info('update_model: No model update was provided [party_id={}]'.format(self.party_id))
         except Exception as ex:
-            raise LocalTrainingException(
-                'No query information is provided. '+ str(ex))
+            raise LocalTrainingException('update_model: [party_id={}] [ex={}]'.format(self.party_id, ex))
+        return status
+
+    def sync_model_impl(self, payload=None):
+        status = False
+        model_update = payload['model_update']
+        status = self.update_model(model_update)
+        return status
+
+    def sync_model(self, payload=None):
+        if not hasattr(self, 'party_id'):
+            logger.info('sync_model: Called before initialization')
+            return
+        logger.info('sync_model: Begin [party_id={}]'.format(self.party_id))
+        return super().sync_model(payload)
 
     def train(self, fit_params=None):
         """
@@ -81,6 +90,10 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
         :return: Returns the corresponding values depending on the function \
         remotely called from the aggregator.
         """
+        logger.info('train: Begin [func={}]'.format(
+            fit_params['func'] if isinstance(fit_params, dict) and 'func' in fit_params else None))
+        logger.debug('train: [fit_params={}]'.format(fit_params))
+
         result = None
         try:
             # Validate Incoming Payload Parameter
@@ -113,9 +126,10 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
             raise LocalTrainingException('Error processing remote function ' +
                                          'call: ' + str(ex))
 
+        logger.info('train: End')
         return result
 
-    def initialize(self, params):
+    def initialize(self, params, party_id=None, last_step='update_raw_preds'):
         """
         A remote function call which performs the following procedures:
         1. Obtains global hyperparameters from the aggregator and initializes
@@ -133,27 +147,31 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
         :type params: `dict`
         :return: Dictionary containing parameters necessary for tree growth at \
         the aggregator.
+        :param last_step: The last function call in a training round. Default to support pre-get_metrics  
+        :type last_step: `string`
         :rtype: `dict`
         """
         # Initialize Hyperparameters
-        logger.info('Recieved and initializing local hyperparameters.')
+        logger.info('initialize: Received and initializing local hyper-parameters [party_id={}]'.format(
+            party_id))
+        self.party_id = party_id
         self.hyperparams = params
-
-        init_parameters(self, params)
+        self.last_step = last_step
 
         logger.info(
-            'Performing preliminary checks, validation, and initialization.')
+            'initialize: Performing preliminary checks and initialization.')
+        init_parameters(self, params)
 
         # Data Validation and Encoding Checks
-        logger.info('[CHECK] Dataset Encoding and Validation Checks')
-        self.data_val_enc()
+        logger.info('initialize: [CHECK] Dataset Encoding and Validation Checks')
+        self.__data_val_enc()
 
         # Check PRNG State
-        logger.info('[CHECK] PRNG State and Seed Validation')
-        self.check_prng_state()
+        logger.info('initialize: [CHECK] PRNG State and Seed Validation')
+        self.__check_prng_state()
 
         # Initialize Key Parameters
-        logger.info('[CHECK] Initialize Key Parameters')
+        logger.info('initialize: [CHECK] Initialize Key Parameters')
         self.loss_ = self.get_loss(sample_weight=self.sample_weight)
 
         # Validate Dataset
@@ -161,7 +179,7 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
         self.X_val, self.y_val = None, None
 
         # Check for Missing Data
-        logger.info('[CHECK] Check for Missing Data')
+        logger.info('initialize: [CHECK] Check for Missing Data')
         self.has_missing_values = np.isnan(
             self.X_train).any(axis=0).astype(np.uint8)
 
@@ -176,29 +194,75 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
 
         return params
 
-    def check_prng_state(self):
+    def init_rejoin(self, party_id, params, curr_round, baseline, model_update, last_step='update_raw_preds'):
+        """
+        Initializes the current party when it rejoins the quorum after dropping.
+
+        :return: `Bool`
+        """
+
+        logger.info('init_rejoin: Begin [party_id={}] [curr_round={}]'.format(party_id, curr_round))
+
+        self.n_completed_trains = curr_round - 1
+        self.n_completed_trains_at_rejoin = curr_round
+
+        try:
+            logger.info('init_rejoin: Calling initialize [party_id={}]'.format(party_id))
+            self.initialize(params=params, party_id=party_id, last_step=last_step)
+            logger.info('init_rejoin: Calling generate_sketch [party_id={}]'.format(party_id))
+            self.generate_sketch()
+            logger.info('init_rejoin: Calling init_null_preds [party_id={}]'.format(party_id))
+            self.init_null_preds(baseline)
+            logger.info('init_rejoin: Calling init_grad [party_id={}]'.format(party_id))
+            self.init_grad()
+            if self.metrics_recorder:
+                self.metrics_recorder.add_entry()
+                self.metrics_recorder.set_round_no(self.get_n_completed_trains())
+            logger.info('init_rejoin: Calling update_grad [party_id={}]'.format(party_id))
+            self.update_grad()
+            logger.info('init_rejoin: Calling sync_model [party_id={}]'.format(party_id))
+            self.update_model(model_update)
+            self.n_completed_trains += 1
+        except Exception as ex:
+            if hasattr(self, 'party_id'):
+                delattr(self, 'party_id')
+            logger.exception('init_rejoin: [party_id={}] encountered an exception and must restart to rejoin [ex={}]'.format(
+                party_id, ex))
+            return (party_id, False)
+
+        logger.info('init_rejoin: End [party_id={}]'.format(party_id))
+
+        return (party_id, True)
+
+    def __check_prng_state(self):
         """
         Given the initialize `random_state` from the hyperparameter, we set the
         random seed value of the local training handler.
 
         :return: `None`
         """
-        # Check PRNG Random State
         rng = check_random_state(self.random_state)
         self._random_seed = rng.randint(np.iinfo(np.uint32).max, dtype='u8')
 
-    def generate_sketch(self, party_id):
-        logger.info('Generate Local Party Data Sketch')
+    def generate_sketch(self, party_id=None):
+
+        if not hasattr(self, 'party_id'):
+            logger.info('generate_sketch: Called before initialization')
+            return
+        if self.party_id is None:
+            self.party_id = party_id
+
+        logger.info('generate_sketch: Generate Local Party Data Sketch [party_id={}]'.format(self.party_id))
 
         # Initialize Local Party Data Parameters
         self.n_samples = self.X_train.shape[0]
 
         # Initialize Sketch - TODO: Parameterize the sketch to choose sketch type.
-        logger.info('> Initialize Feature-Wise Sketchers')
+        logger.info('generate_sketch: > Initialize Feature-Wise Sketchers')
         self.sketchers = [DDSketch() for i in range(self.X_train.shape[1])]
 
         # Append Data to Sketch - TODO: Parallelize this process if necessary.
-        logger.info('> Allocate Data to Sketch Objects')
+        logger.info('generate_sketch: > Allocate Data to Sketch Objects')
         for f_idx in range(self.X_train.shape[1]):
             for x in self.X_train[:, f_idx]:
                 if x != np.NaN:
@@ -206,13 +270,12 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
                     self.sketchers[f_idx].add(x)
 
         # Obtain Percentile Data
-        logger.info('> Generate Percentile Representations of Training Dataset')
-        get_ptile = lambda x, y: stats.percentileofscore(x, y) if not math.isnan(y) else -1
-        self.X_ptiles_train = []
-        for idx in range(self.X_train.shape[0]):
-            self.X_ptiles_train.append([get_ptile(self.X_train[:, f_idx], \
-                self.X_train[idx, f_idx]) for f_idx in range(self.X_train.shape[1])])
-        self.X_ptiles_train = np.array(self.X_ptiles_train)
+        logger.info('generate_sketch: > Generate Percentile Representations of Training Dataset')
+        masked_x_train = np.ma.masked_invalid(self.X_train)
+        self.X_ptiles_train = np.transpose(np.array([
+            np.zeros_like(masked_x_train[:,idx]) if masked_x_train[:,idx].mask.all() else
+             mstats.rankdata(masked_x_train[:, idx]) * 100 / masked_x_train.shape[0] for idx in range(masked_x_train.shape[1]) ]))
+        self.X_ptiles_train[self.X_ptiles_train == 0] = -1
 
         # Perform Data Compression of Percentile Data (Experimental)
         # TODO: Enable this in a future release.
@@ -226,29 +289,11 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
             comp_size = sys.getsizeof(X_ptile_train_compressed)
             ratio = (orig_size - comp_size) / orig_size
 
-            logger.info('> Compression Ratio: ' + str(ratio))
+            logger.info('generate_sketch: > Compression Ratio: ' + str(ratio))
 
             # Transmit X_ptile_train_compressed and data_dim to Aggregator
 
-        return party_id, self.sketchers, self.X_ptiles_train
-
-    def set_cat_bitsets(self, known_cat_bitsets, f_idx_map):
-        """
-        Redistribute the known cateogrical bitset values from the aggregator's
-        bin mapper function back to the local party's fl model object. These
-        two parameters are now required for performing inference over raw data.
-
-        :param known_cat_bitsets: Array of bitsets of known categories, for \
-        each categorical feature. Numpy dimension of (n_categorical_features, 8)
-        :type: kwown_cat_bitsets: `np.array`
-        :param f_idx_map: Map from original feature index to the corresponding \
-        index in the known_cat_bitsets array. Numpy dimension of (n_features,)
-        :type: f_idx_map: `np.array`
-
-        :return: `None`
-        """
-        self.fl_model.known_cat_bitsets = known_cat_bitsets
-        self.fl_model.f_idx_map = f_idx_map
+        return self.party_id, self.sketchers, self.X_ptiles_train
 
     def init_null_preds(self, baseline):
         """
@@ -261,8 +306,14 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
 
         :return: `None`
         """
+
+        if not hasattr(self, 'party_id'):
+            logger.info('init_null_preds: Called before initialization')
+            return
+
+        logger.info('init_null_preds: Generating Initial Predictions from Null Model [party_id={}]'.format(self.party_id))
+
         # Generate Baseline Predictions
-        logger.info('Generating Initial Predictions from Null Model')
         self.baseline = baseline
         self.raw_predictions = np.zeros(shape=(self.n_samples, self.n_trees),
                                         dtype=self.baseline.dtype) + self.baseline
@@ -273,7 +324,6 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
         self.raw_predictions_val = None
         self.train_score_ = []
         self.validation_score_ = []
-
         self.begin_at_stage = 0
 
         # Initialize Model Attributes
@@ -297,6 +347,13 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
 
         :return: `None`
         """
+
+        if not hasattr(self, 'party_id'):
+            logger.info('init_grad: Called before initialization')
+            return
+
+        logger.info('init_grad: Begin [party_id={}]'.format(self.party_id))
+
         self.gradient, self.hessian = self.loss_.init_gradient_and_hessian(
             n_samples=self.n_samples,
             dtype=G_H_DTYPE,
@@ -311,6 +368,16 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
 
         :return: `None`
         """
+
+        if not hasattr(self, 'party_id'):
+            logger.info('update_grad: Called before initialization')
+            return
+
+        logger.info('update_grad: Begin [party_id={}]'.format(self.party_id))
+
+        if not hasattr(self, 'n_completed_trains_at_rejoin') or self.n_completed_trains > self.n_completed_trains_at_rejoin:
+            self.get_train_metrics_pre()
+
         if self.loss_.constant_hessian:
             self.loss_.gradient(
                 y_true=self.y_train,
@@ -327,24 +394,58 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
                 hessian_out=self.hessian
             )
 
-    def collect_hist(self, party_id, k):
+    def collect_hist(self, k, party_id=None):
         """
         We return values of the surrogate histogram values, gradients, hessians,
         and the number of non-missing bin counts from the local worker.
 
-        :param k: The correseponding feature index of the dataset.
+        :param k: The corresponding feature index of the dataset.
         :type k: `int`
         :return: Returns a tuple comprising of the histogram bin index values, \
         gradient, hessian, missing value counts per feature, bin threshold value.
         :rtype: (`np.array`, `np.array`, `np.array`, `list`, `list`)
         """
+
+        if not hasattr(self, 'party_id'):
+            logger.info('collect_hist: Called before initialization')
+            return
+        if self.party_id is None:
+            self.party_id = party_id
+
+        logger.info('collect_hist: Begin [party_id={}]'.format(self.party_id))
+
         if self.gradient.ndim == 1:
                 g_view = self.gradient.reshape((-1, 1))
                 h_view = self.hessian.reshape((-1, 1))
         else:
                 g_view = self.gradient
                 h_view = self.hessian
-        return party_id, g_view[:, k], h_view[:, k]
+        return self.party_id, g_view[:, k], h_view[:, k]
+
+    def set_cat_bitsets(self, known_cat_bitsets, f_idx_map):
+        """
+        Redistribute the known cateogrical bitset values from the aggregator's
+        bin mapper function back to the local party's fl model object. These
+        two parameters are now required for performing inference over raw data.
+
+        :param known_cat_bitsets: Array of bitsets of known categories, for \
+        each categorical feature. Numpy dimension of (n_categorical_features, 8)
+        :type: kwown_cat_bitsets: `np.array`
+        :param f_idx_map: Map from original feature index to the corresponding \
+        index in the known_cat_bitsets array. Numpy dimension of (n_features,)
+        :type: f_idx_map: `np.array`
+
+        :return: `None`
+        """
+
+        if not hasattr(self, 'party_id'):
+            logger.info('set_cat_bitsets: Called before initialization')
+            return
+
+        logger.info('set_cat_bitsets: Begin [party_id={}]'.format(self.party_id))
+
+        self.fl_model.known_cat_bitsets = known_cat_bitsets
+        self.fl_model.f_idx_map = f_idx_map
 
     def update_raw_preds(self, k, predictor):
         """
@@ -363,6 +464,14 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
 
         :return: `None`
         """
+
+        if not hasattr(self, 'party_id'):
+            logger.info('update_raw_preds: Called before initialization')
+            return
+
+        logger.info('update_raw_preds: Begin [party_id={}]'.format(self.party_id))
+        logger.debug('update_raw_preds: [k={}] [predictor={}]'.format(k, predictor))
+
         # Define Predict Function
         predict = partial(
             predictor.predict,
@@ -374,14 +483,14 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
         # Update Raw Prediction
         self.raw_predictions[:, k] += predict(self.X_train)
 
-    def data_val_enc(self):
+    def __data_val_enc(self):
         """
         Performs a validation procedure of the input dataset to correspondingly
         check the data types as well as the data encoding.
 
         :return: `None`
         """
-        logging.info('Performing local worker data encoding and validation.')
+
         (x, y), (_) = self.data_handler.get_data()
 
         # Perform Data Encoding Validation
@@ -400,13 +509,59 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
         :type  in_fit: `Boolean`
         :return: `None`
         """
+
+        if not hasattr(self, 'party_id'):
+            logger.info('set_fit: Called before initialization')
+            return
+
+        logger.info('set_fit: Begin [party_id={}]'.format(self.party_id))
+
         self.fl_model._in_fit = in_fit
 
+    def get_metrics(self):
+        """
+        Returns party side metrics.
+        Adding the metrics to the reply message is done by party_protocol_handler.py.
+        Therefore, this function returns None as the payload part.
+
+        :return: `None`
+        """
+
+        if not hasattr(self, 'party_id'):
+            logger.info('get_metrics: Called before initialization')
+            return None
+
+        logger.info('get_metrics: Begin [party_id={}]'.format(self.party_id))
+
+        self.get_train_metrics_post()
+
+        return None
+
+    def determine_train_msg_seq(self, message_type, payload: dict):
+        """
+        Determines if the specific training message is the first or the last in a training round sequence.
+
+        :param message_type: The type of the message.
+        :type message_type: `enum`
+        :param payload: Payload of the message.
+        :type payload: `dict`
+        :return: Tuple indicating if the message is first or last.
+        :rtype: `tuple`
+        """
+        first_step = last_step = False
+        if message_type is MessageType.TRAIN.value:
+            first_step = (payload.get('func') == 'update_grad')
+            if hasattr(self,'last_step'):
+                if 'update_raw_preds' == self.last_step:
+                    last_step = (payload.get('func') == self.last_step) and (self.n_trees-1) == payload.get('args').get('k')
+                else: 
+                    last_step = (payload.get('func') == self.last_step)
+        return (first_step, last_step)
+
     @abstractmethod
     def encode_target(self, y=None):
         raise NotImplementedError
 
-
 class XGBRegressorLocalTrainingHandler(XGBoostBaseLocalTrainingHandler):
     _VALID_LOSSES = ('least_squares')
 
@@ -445,12 +600,16 @@ class XGBRegressorLocalTrainingHandler(XGBoostBaseLocalTrainingHandler):
         :return: Returns y_hat * n and n.
         :rtype: (`np.array`, `np.array`)
         """
-        logger.info('Compute Local Party Average Statistics')
+
+        if not hasattr(self, 'party_id'):
+            logger.info('get_avg_stats: Called before initialization')
+            return
+
+        logger.info('get_avg_stats: Compute Local Party Average Statistics [party_id={}]'.format(self.party_id))
 
         return (np.array(np.average(self.y_train, weights=self.sample_weight)), \
                 np.array([len(self.y_train)]))
 
-
 class XGBClassifierLocalTrainingHandler(XGBoostBaseLocalTrainingHandler):
     _VALID_LOSSES = ('binary_crossentropy', 'categorical_crossentropy', 'auto')
 
@@ -523,7 +682,12 @@ class XGBClassifierLocalTrainingHandler(XGBoostBaseLocalTrainingHandler):
         :return: Returns y_hat * n and n.
         :rtype: (`np.array`, `np.array`)
         """
-        logger.info('Compute Local Party Average Statistics')
+
+        if not hasattr(self, 'party_id'):
+            logger.info('get_avg_stats: Called before initialization')
+            return
+
+        logger.info('get_avg_stats: Compute Local Party Average Statistics [party_id={}]'.format(self.party_id))
 
         # Compute Average Depending on the Value
         if (self.n_trees == 1) or self.loss == 'binary_crossentropy':
@@ -536,13 +700,3 @@ class XGBClassifierLocalTrainingHandler(XGBoostBaseLocalTrainingHandler):
                                weights=self.sample_weight))
                 counts.append(len(self.y_train == k))
             return (np.array(average), np.array(counts))
-
-    def should_incr_n_completed_trains(self, payload):
-        """
-        Increment the number of completed executions of the TRAIN command at the party side
-
-        :param: payload: dict
-        """
-        return (payload['func'] == 'update_raw_preds')
-
-
