@@ -1,28 +1,17 @@
-#  (C) Copyright IBM Corp. 2021-2023.
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#       http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
-
+#  -----------------------------------------------------------------------------------------
+#  (C) Copyright IBM Corp. 2021- 2023.
+#  https://opensource.org/licenses/BSD-3-Clause
+#  -----------------------------------------------------------------------------------------
 import logging
 import asyncio
 import threading
 import websockets
-from _collections import deque
+from collections import deque
 import signal
 import ssl
 import time
 import concurrent.futures._base
 
-from ibmfl.connection.connection import ConnectionStatus
 from ibmfl.connection.connection import FLConnection, FLSender, FLReceiver
 from ibmfl.message.message import Message, ResponseMessage
 from ibmfl.message.message_type import MessageType
@@ -31,6 +20,9 @@ from ibmfl.message.serializer_factory import SerializerFactory
 
 logger = logging.getLogger(__name__)
 
+# This variable MUST be set to False in production. It can be set to True only in local testing environment.
+TEST_MODE = False
+
 #TODO: remove  self.temp_rts_id = '4a666f4a-87c0-475d-bfb2-312d186163b4' 
 
 party_rbuffer = deque([])
@@ -112,6 +104,7 @@ class SWSReceiver(FLReceiver):
         self.stop = None
         self.messageInTransit = None
         self.stoppedStateObj = None
+        self.registered = False
 
     def initialize(self, **kwargs):
         pass
@@ -179,22 +172,35 @@ class SWSReceiver(FLReceiver):
 
 
     async def establish_websocket_connection(self, loop, stop):
-        logger.debug("METHOD = SWSReceiver.establish_websocket_connection")
-        uri = "wss://" + self.settings.get("ip") + ":" + str(self.settings.get("port"))
-        logger.debug("SWSReceiver.establish_websocket_connection uri = "+uri)
+        prefix = "wss://" if not TEST_MODE else "ws://"
+        uri = prefix + self.settings.get("ip") + ":" + str(self.settings.get("port"))
+        logger.info("METHOD = SWSReceiver.establish_websocket_connection uri = "+uri)
 
         headers = { 'rtsid': self.party }
         token = self.settings.get('token')
         if ( token is not None ):
             headers['Authorization'] = token
         if ( not self.settings.get('verify') ) :
-            self.ssl_context = ssl.SSLContext()
+            self.ssl_context = ssl.SSLContext() if not TEST_MODE else None
         logger.debug("SWSReceiver.establish_websocket_connection ssl = "+str(self.ssl_context))
         apikey_header = None
         while not self.stopped:
             try:
                 logger.debug("SWSReceiver.establish_websocket_connection ATTEMPT async websockets.connect")
-                async with websockets.connect(uri, open_timeout=30, ping_interval=20, ping_timeout=None, max_size=2 ** 29, read_limit=2 ** 29, write_limit=2**29, ssl=self.ssl_context, loop=loop, extra_headers=headers) as websocket:
+
+                connect_params = {
+                    'ping_interval': 20,
+                    'ping_timeout': None,
+                    'max_size': 2 ** 29,
+                    'read_limit': 2 ** 29,
+                    'write_limit': 2**29,
+                    'loop': loop,
+                    'extra_headers': headers
+                }
+                if not TEST_MODE:
+                    connect_params['ssl'] = self.ssl_context
+                async with websockets.connect(uri, **connect_params) as websocket:
+
                     logger.info("Received Heartbeat from Aggregator")
                     apikey_header = websocket.response_headers.get("apikey", None)
                     if apikey_header is not None:
@@ -277,7 +283,7 @@ class SWSReceiver(FLReceiver):
         logger.debug("METHOD = SWSReceiver.receive_message_handler")
         try:
             async for message in websocket:
-                logger.debug("METHOD = SWSReceiver.receive_message_handler")
+                logger.debug("METHOD = SWSReceiver.receive_message_handler message")
                 self.debug_websocket(websocket)
                 await self.process_received_message(message)
                 #logger.info(message)
@@ -347,6 +353,7 @@ class SWSReceiver(FLReceiver):
         message_type = str(recv_msg.message_type)
         logger.debug('METHOD = SWSReceiver.process_received_message type = ' + message_type )
 
+
         if (recv_msg.message_type == MessageType.STOP.value):
             handler, kwargs = self.router.get_handler(request_path=message_type)
             if handler is not None:
@@ -376,11 +383,41 @@ class SWSReceiver(FLReceiver):
         #     self.sender.send_message(recv_msg.sender_info, res_message, False)
        
 
+        if not self.registered :
+            if recv_msg.message_type == MessageType.REGISTER.value :
+                logger.info("Processing REGISTER")
+                party_rbuffer.appendleft(recv_msg)
+                logger.info("Signalling for REGISTER")
+                pRecvEvt.set()
+                logger.info("Waiting for REGISTER to be popped to clear backlog")
+                pSendEvt.wait()
+                logger.debug("############# pSendEvt activated")
+                self.registered = True
+                try:
+                    while back_message := party_rbuffer.popleft() :
+                        logger.debug("Handling back_message {}".format(back_message))
+                        self.handle_message(back_message)
+                except IndexError:
+                    logger.debug("Popped backlog")
+                logger.debug("Clearing send evt")
+                pSendEvt.clear()
+            else:
+                logger.info("Not registered - stashing message")
+                party_rbuffer.append(recv_msg)
+                
+            return
+
+        self.handle_message(recv_msg)
+    
+    def handle_message(self, recv_msg):
+
+        message_type = str(recv_msg.message_type)
 
         handler, kwargs = self.router.get_handler(request_path=message_type)
 
-        if handler is None:
+        logger.info("Handler for message type {} is {}".format(message_type,handler))
 
+        if handler is None :
             party_rbuffer.append(recv_msg)
             pRecvEvt.set()
 
@@ -451,6 +488,7 @@ class SWSSender(FLSender):
             pRecvEvt.clear()
             logger.debug(
                 'Received serialized message as response: ' + str(response_message))
+            pSendEvt.set()
 
             return response_message
 
