@@ -515,12 +515,17 @@ class ModelDefinition(WMLResource):
 
         return attachment_id
 
-    def list(self, limit=None):
+    def list(self, limit=None, return_as_df=True):
         """Print stored model definition assets in a table format.
         If limit is set to None there will be only first 50 records shown.
 
         :param limit: limit number of fetched records
         :type limit: int, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed model definitions or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
@@ -551,7 +556,10 @@ class ModelDefinition(WMLResource):
             (m[u'metadata'][u'name'], m[u'metadata'][u'asset_type'], m[u'metadata'][u'asset_id']) for
             m in asset_details]
 
-        self._list(model_def_values, [u'NAME', u'ASSET_TYPE', u'GUID'], limit, _DEFAULT_LIST_LENGTH)
+        table = self._list(model_def_values, [u'NAME', u'ASSET_TYPE', u'GUID'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
+
 
     def get_id(self, model_definition_details):
         """Get Unique Id of stored model definition asset.
