@@ -353,6 +353,9 @@ class Party(WMLResource):
                         software_spec = "runtime-22.1-py3.9"
                     platform_env = choose_software_version(software_spec)
                     print("Loading {} environment..".format(platform_env))
+                    if "system" in details and "warnings" in details["system"]:
+                        for warning in details["system"]["warnings"]:
+                            print("Warning: {}".format(warning["message"]))
                     self.module_location = '/'.join(self.module_location.split('/')[0:-2]) + self.SUPPORTED_PLATFORMS_MAP.get(platform_env)
                 import_diff(self.module_location)
                 from ibmfl.party.party import Party
