@@ -104,7 +104,7 @@ class Pipelines(WMLResource):
                 ]
               }
         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or \
-                self._client.ICP_45 or self._client.ICP_46:
+                self._client.ICP_45 or self._client.ICP_46 or self._client.ICP_47:
             if self.ConfigurationMetaNames.COMMAND in meta_props:
                 doc["pipelines"][0]["nodes"][0]["parameters"]["command"] = meta_props[self.ConfigurationMetaNames.COMMAND]
             if self.ConfigurationMetaNames.RUNTIMES in meta_props:
@@ -203,7 +203,7 @@ class Pipelines(WMLResource):
                 raise WMLClientError("It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/client.set.default_project(<PROJECT_UID>) to proceed.")
 
         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or \
-                self._client.ICP_45 or self._client.ICP_46:
+                self._client.ICP_45 or self._client.ICP_46 or self._client.ICP_47:
             if self._client.default_space_id is not None:
                 pipeline_meta['space_id'] = self._client.default_space_id
             elif self._client.default_project_id is not None:
@@ -286,7 +286,7 @@ class Pipelines(WMLResource):
                 pipeline_details = self._handle_response(201, u'creating new pipeline', creation_response)
                 return WMLResource._wsd_get_required_element_from_response(self, pipeline_details)
 
-            elif self._client.ICP_35 or self._client.ICP_40 or self._client.ICP_45 or self._client.ICP_46:
+            elif self._client.ICP_35 or self._client.ICP_40 or self._client.ICP_45 or self._client.ICP_46 or self._client.ICP_47:
                 creation_response = requests.post(
                     self._client.service_instance._href_definitions.get_pipelines_href(),
                     headers=self._client._get_headers(),
@@ -323,7 +323,7 @@ class Pipelines(WMLResource):
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', str, False)
 
         if not any([self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
-                    self._client.ICP_45, self._client.ICP_46]):
+                    self._client.ICP_45, self._client.ICP_46, self._client.ICP_47]):
             raise WMLClientError(
                 u'Revision support is not there in this version WML server. It is supported only from 3.1.0 onwards.')
         else:
@@ -473,7 +473,7 @@ class Pipelines(WMLResource):
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', str, True)
         Pipelines._validate_type(rev_uid, u'rev_uid', int, True)
         if not any([self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
-                    self._client.ICP_45, self._client.ICP_46]):
+                    self._client.ICP_45, self._client.ICP_46, self._client.ICP_47]):
             raise WMLClientError(
                 'Not supported. Revisions APIs are supported only for IBM Cloud Pak® for Data 3.0 and above.')
         else:
@@ -568,12 +568,18 @@ class Pipelines(WMLResource):
             return WMLResource._get_required_element_from_dict(pipeline_details, u'pipeline_details',
                                                                [u'metadata', u'id'])
 
-    def list(self, limit=None):
+    def list(self, limit=None, return_as_df=True):
         """Print stored pipelines in a table format. If limit is set to None there will be only first 50 records shown.
 
         :param limit: limit number of fetched records
         :type limit: int, optional
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed pipelines or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
         **Example**
 
         .. code-block:: python
@@ -581,7 +587,7 @@ class Pipelines(WMLResource):
             client.pipelines.list()
 
         """
-
+        table = None
         if self._client.WSD:
             Pipelines._wsd_list_assets(self, "wml_pipeline", limit)
         else:
@@ -590,17 +596,19 @@ class Pipelines(WMLResource):
 
             pipeline_resources = self.get_details(limit=limit)[u'resources']
             if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or \
-                    self._client.ICP_45 or self._client.ICP_46:
+                    self._client.ICP_45 or self._client.ICP_46 or self._client.ICP_47:
                 pipeline_values = [(m[u'metadata'][u'id'], m[u'metadata'][u'name'], m[u'metadata'][u'created_at']) for m
                                    in pipeline_resources]
 
-                self._list(pipeline_values, [u'ID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+                table = self._list(pipeline_values, [u'ID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
             else:
                 pipeline_values = [(m[u'metadata'][u'id'], m[u'entity'][u'name'], m[u'metadata'][u'created_at']) for m in pipeline_resources]
 
-                self._list(pipeline_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+                table = self._list(pipeline_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
-    def list_revisions(self, pipeline_uid, limit=None):
+    def list_revisions(self, pipeline_uid, limit=None, return_as_df=True):
         """Print all revision for the given pipeline uid in a table format.
 
         :param pipeline_uid: Unique id of stored pipeline
@@ -609,6 +617,12 @@ class Pipelines(WMLResource):
         :param limit: limit number of fetched records
         :type limit: int, optional
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed revisions or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
         **Example**
 
         .. code-block:: python
@@ -620,9 +634,9 @@ class Pipelines(WMLResource):
         self._client._check_if_either_is_set()
 
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', str, True)
-
+        table = None
         if not any([self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
-                    self._client.ICP_45, self._client.ICP_46]):
+                    self._client.ICP_45, self._client.ICP_46, self._client.ICP_47]):
             raise WMLClientError(
                 u'Revision support is not there in this WML server. It is supported only from 3.1.0 onwards.')
         else:
@@ -632,7 +646,9 @@ class Pipelines(WMLResource):
                 (m[u'metadata'][u'rev'], m[u'metadata'][u'name'], m[u'metadata'][u'created_at']) for m in
                 pipeline_resources]
 
-            self._list(pipeline_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+            table = self._list(pipeline_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     def clone(self, pipeline_uid, space_id=None, action="copy", rev_id=None):
         """Create a new pipeline identical with the given pipeline either in the same space or in a new space.
@@ -663,7 +679,7 @@ class Pipelines(WMLResource):
 
         """
         if any([self._client.WSD, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
-                self._client.ICP_45, self._client.ICP_46]):
+                self._client.ICP_45, self._client.ICP_46, self._client.ICP_47]):
             raise WMLClientError(" Clone pipeline operation is not supported. ")
         Pipelines._validate_type(pipeline_uid, 'exp_id', str, True)
         clone_meta = {}
