@@ -124,21 +124,27 @@ class PkgExtn(WMLResource):
                 index = 0
                 headers = {}
 
-                for chunk in read_in_chunks(FILE_SIZE_LIMIT):
-                    offset = index + len(chunk)
-                    headers['Content-Range'] = 'bytes %s-%s/%s' % (index, offset - 1, content_size)
-                    index = offset
+                try:
+                    for chunk in read_in_chunks(FILE_SIZE_LIMIT):
+                        offset = index + len(chunk)
+                        headers['Content-Range'] = 'bytes %s-%s/%s' % (index, offset - 1, content_size)
+                        index = offset
 
-                    response = requests.put(
-                        url,
-                        files={"file": (file, chunk, 'application/octet-stream')}
+                        response = requests.put(
+                            url,
+                            files={"file": (file, chunk, 'application/octet-stream')}
+                        )
+                except Exception as e:
+                    deletion_response = requests.delete(
+                        self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_asset_id),
+                        params=self._client._params(),
+                        headers=self._client._get_headers()
                     )
+                    print(deletion_response.status_code)
+                    raise WMLClientError("Failed while reading a file.", e)
 
                 return response
 
-            if os.stat(file_path).st_size == 0:
-                raise WMLClientError('Package extension file cannot be empty')
-
             # chunking, when finally it will work on service side. to confirm it's working, the downloaded file needs to be the same as 400MB+ upladed file
             #
             # put_response = send_multipart_request(file_path,
@@ -146,19 +152,30 @@ class PkgExtn(WMLResource):
 
             href = (self._client.service_instance._wml_credentials['url'] if self._client.ICP else "") + pkg_extn_presigned_url
 
-
             # if pkg_extn_details["entity"]["package_extension"]["type"] in ["conda_yml", "pip_zip"]:
-            with open(file_path, 'rb') as file_object:
-                if not self._client.ICP:
-                    put_response = requests.put(
-                        href,
-                        data=file_object.read()
-                    )
-                else:
-                    put_response = requests.put(
-                        href,
-                        files={'file': (file_path, file_object.read(), 'application/octet-stream')}
-                    )
+            try:
+                if os.stat(file_path).st_size == 0:
+                    raise WMLClientError('Package extension file cannot be empty')
+
+                with open(file_path, 'rb') as file_object:
+                    if not self._client.ICP:
+                        put_response = requests.put(
+                            href,
+                            data=file_object.read()
+                        )
+                    else:
+                        put_response = requests.put(
+                            href,
+                            files={'file': (file_path, file_object.read(), 'application/octet-stream')}
+                        )
+            except Exception as e:
+                deletion_response = requests.delete(
+                    self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_asset_id),
+                    params=self._client._params(),
+                    headers=self._client._get_headers()
+                )
+                print(deletion_response.status_code)
+                raise WMLClientError("Failed while reading a file.", e)
 
             if put_response.status_code == 201 or put_response.status_code == 200:
                 # Step3: Mark the upload complete
@@ -180,8 +197,14 @@ class PkgExtn(WMLResource):
         else:
             raise WMLClientError("Failed while creating a package extensions " + creation_response.text)
 
-    def list(self):
-        """Print package extensions in a table format.
+    def list(self, return_as_df=True):
+        """List package extensions in a table format.
+
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed package extensions or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         .. code-block:: python
 
@@ -202,7 +225,9 @@ class PkgExtn(WMLResource):
              m[u'metadata'][u'created_at']) for
             m in asset_details]
 
-        self._list(pkg_extn_values, [u'NAME', u'ASSET_ID', u'TYPE', u'CREATED_AT'], None, _DEFAULT_LIST_LENGTH)
+        table = self._list(pkg_extn_values, [u'NAME', u'ASSET_ID', u'TYPE', u'CREATED_AT'], None, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     @staticmethod
     def get_uid(pkg_extn_details):
