@@ -297,7 +297,7 @@ class PlatformSpaces(WMLResource):
                                                    _async=asynchronous,
                                                    _all=get_all)
 
-    def list(self, limit=None, member=None, roles=None):
+    def list(self, limit=None, member=None, roles=None, return_as_df=True):
         """Print stored spaces in a table format. If limit is set to None there will be only first 50 records shown.
 
         :param limit: limit number of fetched records
@@ -307,6 +307,11 @@ class PlatformSpaces(WMLResource):
         :type member: str, optional
         :param roles: limit number of fetched records
         :type roles: str, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed spaces or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
@@ -344,7 +349,10 @@ class PlatformSpaces(WMLResource):
             print("Note: 'limit' is not provided. Only first 50 records will be displayed if the number of records "
                   "exceed 50")
 
-        self._list(space_values, [u'ID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+        table = self._list(space_values, [u'ID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
+
 
     def update(self, space_id, changes):
         """Updates existing space metadata. 'STORAGE' cannot be updated.
@@ -622,7 +630,7 @@ class PlatformSpaces(WMLResource):
 
         return updated_details
 
-    def list_members(self, space_id, limit=None, identity_type=None, role=None, state=None):
+    def list_members(self, space_id, limit=None, identity_type=None, role=None, state=None, return_as_df=True):
         """Print stored members of a space in a table format.
         If limit is set to None there will be only first 50 records shown.
 
@@ -636,6 +644,11 @@ class PlatformSpaces(WMLResource):
         :type role: str, optional
         :param state: filter the members by state
         :type state: str, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed members or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
@@ -693,10 +706,12 @@ class PlatformSpaces(WMLResource):
             print("Note: 'limit' is not provided. Only first 50 records will be displayed if the number of records "
                   "exceed 50")
 
-        self._list(space_values, [u'ID',
-                                  u'TYPE',
-                                  u'ROLE',
-                                  u'STATE'], limit, _DEFAULT_LIST_LENGTH)
+        table = self._list(space_values, [u'ID',
+                                          u'TYPE',
+                                          u'ROLE',
+                                          u'STATE'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     def promote(self, asset_id: str, source_project_id: str, target_space_id: str, rev_id: str = None) -> str:
         """Promote asset from project to space.
