@@ -170,12 +170,12 @@ class Repository(WMLResource):
     @inherited_docstring(Models.store, {'store()': 'store_model()'})
     def store_model(self, model, meta_props=None, training_data=None, training_target=None, pipeline=None,
                     feature_names=None, label_column_names=None,subtrainingId=None, round_number=None,
-                    experiment_metadata=None):
+                    experiment_metadata=None, training_id=None):
         return self._client._models.store(model, meta_props=meta_props, training_data=training_data,
                                           training_target=training_target, pipeline=pipeline,
                                           feature_names=feature_names, label_column_names=label_column_names,
                                           subtrainingId=subtrainingId, round_number=round_number,
-                                          experiment_metadata=experiment_metadata)
+                                          experiment_metadata=experiment_metadata, training_id=training_id)
 
     def clone(self, artifact_id, space_id=None, action="copy", rev_id=None):
         # """ it is not supported in v4ga
@@ -342,10 +342,10 @@ class Repository(WMLResource):
         elif res['function'] is True:
             return self._client._functions.download(artifact_uid, filename, rev_uid)
         elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40  \
-                and not self._client.ICP_45 and not self._client.ICP_46 and res['library'] is True:
+                and not self._client.ICP_45 and not self._client.ICP_46 and not self._client.ICP_47 and res['library'] is True:
             return self._client.runtimes.download_library(artifact_uid, filename)
         elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40 \
-                and not self._client.ICP_45 and not self._client.ICP_46 and res['runtime'] is True:
+                and not self._client.ICP_45 and not self._client.ICP_46 and not self._client.ICP_47 and res['runtime'] is True:
             return self._client.runtimes.download_configuration(artifact_uid, filename)
         else:
             raise WMLClientError('Unexpected type of artifact to download or Artifact with artifact_uid: \'{}\' does not exist.'.format(artifact_uid) )
@@ -820,42 +820,42 @@ class Repository(WMLResource):
              print('Note: Only first {} records were displayed. To display more use more specific list functions.'.format(_DEFAULT_LIST_LENGTH))
 
     @inherited_docstring(Models.list)
-    def list_models(self, limit=None, asynchronous=False, get_all=False):
-        return self._client._models.list(limit=limit, asynchronous=asynchronous, get_all=get_all)
+    def list_models(self, limit=None, asynchronous=False, get_all=False, return_as_df=True):
+        return self._client._models.list(limit=limit, asynchronous=asynchronous, get_all=get_all, return_as_df=return_as_df)
 
     @inherited_docstring(Experiments.list)
-    def list_experiments(self, limit=None):
+    def list_experiments(self, limit=None, return_as_df=True):
         if self._client.WSD:
             raise WMLClientError(u'Experiment APIs are not supported for Watson Studio Desktop.')
-        self._client.experiments.list(limit=limit)
+        return self._client.experiments.list(limit=limit,  return_as_df=return_as_df)
 
     @inherited_docstring(Spaces.list)
-    def list_spaces(self, limit=None):
+    def list_spaces(self, limit=None, return_as_df=True):
         if self._client.WSD:
             raise WMLClientError('list_spaces - Listing spaces is not supported for Watson Studio Desktop.')
 
         if Repository.cloud_platform_spaces or Repository.icp_platform_spaces:
             raise WMLClientError(u"Not supported in this release. Use methods in 'client.spaces' instead")
 
-        self._client.spaces.list(limit=limit)
+        return self._client.spaces.list(limit=limit, return_as_df=return_as_df)
 
     @inherited_docstring(Functions.list)
-    def list_functions(self, limit=None):
-        self._client._functions.list(limit=limit)
+    def list_functions(self, limit=None, return_as_df=True):
+        return self._client._functions.list(limit=limit, return_as_df=return_as_df)
 
     @inherited_docstring(Pipelines.list)
-    def list_pipelines(self, limit=None):
-        self._client.pipelines.list(limit=limit)
+    def list_pipelines(self, limit=None, return_as_df=True):
+        return self._client.pipelines.list(limit=limit, return_as_df=return_as_df)
 
     @inherited_docstring(Spaces.list_members)
-    def list_members(self, space_uid, limit=None):
+    def list_members(self, space_uid, limit=None, return_as_df=True):
         if self._client.WSD:
             raise WMLClientError('list_members - Listing members is not supported for Watson Studio Desktop.')
 
         if Repository.cloud_platform_spaces or Repository.icp_platform_spaces:
             raise WMLClientError(u"Not supported in this release. Use methods in 'client.spaces' instead")
 
-        self._client.spaces.list_members(space_uid=space_uid, limit=limit)
+        return self._client.spaces.list_members(space_uid=space_uid, limit=limit, return_as_df=return_as_df)
 
     def _check_artifact_type(self, artifact_uid):
         Repository._validate_type(artifact_uid, u'artifact_uid', str, True)
@@ -983,20 +983,20 @@ class Repository(WMLResource):
         return details
 
     @inherited_docstring(Models.list_revisions)
-    def list_models_revisions(self, model_uid, limit=None):
-        self._client._models.list_revisions(model_uid, limit=limit)
+    def list_models_revisions(self, model_uid, limit=None, return_as_df=True):
+        return self._client._models.list_revisions(model_uid, limit=limit, return_as_df=return_as_df)
 
     @inherited_docstring(Pipelines.list_revisions)
-    def list_pipelines_revisions(self, pipeline_uid, limit=None):
-        self._client.pipelines.list_revisions(pipeline_uid, limit=limit)
+    def list_pipelines_revisions(self, pipeline_uid, limit=None, return_as_df=True):
+        return self._client.pipelines.list_revisions(pipeline_uid, limit=limit, return_as_df=return_as_df)
 
     @inherited_docstring(Functions.list_revisions)
-    def list_functions_revisions(self, function_uid, limit=None):
-        self._client._functions.list_revisions(function_uid, limit=limit)
+    def list_functions_revisions(self, function_uid, limit=None, return_as_df=True):
+        return self._client._functions.list_revisions(function_uid, limit=limit, return_as_df=return_as_df)
 
     @inherited_docstring(Experiments.list_revisions)
-    def list_experiments_revisions(self, experiment_uid, limit=None):
-        self._client.experiments.list_revisions(experiment_uid, limit=limit)
+    def list_experiments_revisions(self, experiment_uid, limit=None, return_as_df=True):
+        return self._client.experiments.list_revisions(experiment_uid, limit=limit, return_as_df=return_as_df)
 
     @inherited_docstring(Models.promote)
     def promote_model(self, model_id: str, source_project_id: str, target_space_id: str):  # deprecated
