@@ -40,7 +40,7 @@ class Script(WMLResource):
 
         .. code-block:: python
 
-            script_details = client.scripts.get_details(script_uid)
+            script_details = client.script.get_details(script_uid)
 
         """
         def get_required_elements(response):
@@ -80,12 +80,12 @@ class Script(WMLResource):
         .. code-block:: python
 
             metadata = {
-                client.script.ConfigurationMetaNamess.NAME: 'my first script',
+                client.script.ConfigurationMetaNames.NAME: 'my first script',
                 client.script.ConfigurationMetaNames.DESCRIPTION: 'description of the script',
                 client.script.ConfigurationMetaNames.SOFTWARE_SPEC_UID: '0cdb0f1e-5376-4f4d-92dd-da3b69aa9bda'
             }
 
-            asset_details = client.scripts.store(meta_props=metadata, file_path="/path/to/file")
+            asset_details = client.script.store(meta_props=metadata, file_path="/path/to/file")
 
         """
         if self._client.project_type == 'local_git_storage':
@@ -180,7 +180,7 @@ class Script(WMLResource):
             sw_spec_details = self._client.software_specifications.get_details(script_meta[u'software_spec_uid'])
 
             if lang == 'R':
-                if self._client.ICP_46:
+                if self._client.ICP_46 or self._client.ICP_47:
                     rscript_sw_specs = ('runtime-22.2-r4.2',)
                     deprecated_rscript_sw_specs = ('default_r3.6', 'runtime-22.1-r3.6',)
                 else:
@@ -378,19 +378,28 @@ class Script(WMLResource):
                     attachment_id = attachment_details["attachment_id"]
                     attachment_url = attachment_details["url1"]
 
-
                     #Step3: Put content to attachment
-                    with open(file_path, 'rb') as f:
-                        if not self._ICP:
-                            put_response = requests.put(
-                                attachment_url,
-                                data=f.read()
-                            )
-                        else:
-                            put_response = requests.put(
-                                self._wml_credentials['url'] + attachment_url,
-                                files={'file': (name, f, 'application/octet-stream')}
-                            )
+                    try:
+                        with open(file_path, 'rb') as f:
+                            if not self._ICP:
+                                put_response = requests.put(
+                                    attachment_url,
+                                    data=f.read()
+                                )
+                            else:
+                                put_response = requests.put(
+                                    self._wml_credentials['url'] + attachment_url,
+                                    files={'file': (name, f, 'application/octet-stream')}
+                                )
+                    except Exception as e:
+                        deletion_response = requests.delete(
+                            self._client.service_instance._href_definitions.get_data_asset_href(asset_id),
+                            params=self._client._params(),
+                            headers=self._client._get_headers()
+                        )
+                        print(deletion_response.status_code)
+                        raise WMLClientError("Failed while reading a file.", e)
+
                     if put_response.status_code == 201 or put_response.status_code == 200:
                         # Step4: Complete attachment
                         complete_response = requests.post(
@@ -416,11 +425,16 @@ class Script(WMLResource):
                 raise WMLClientError("Failed while creating a script asset. Try again.")
 
 
-    def list(self, limit=None):
+    def list(self, limit=None, return_as_df=True):
         """Print stored scripts in a table format. If limit is set to None there will be only first 50 records shown.
 
         :param limit: limit number of fetched records
         :type limit: int, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed scripts or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
@@ -446,7 +460,9 @@ class Script(WMLResource):
             (m[u'metadata'][u'name'], m[u'metadata'][u'asset_type'], m["metadata"]["asset_id"]) for
             m in asset_details]
 
-        self._list(space_values, [u'NAME', u'ASSET_TYPE', u'ASSET_ID'], None, _DEFAULT_LIST_LENGTH)
+        table = self._list(space_values, [u'NAME', u'ASSET_TYPE', u'ASSET_ID'], None, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     def download(self, asset_uid, filename, rev_uid=None):
         """Download the content of a script asset.
@@ -823,7 +839,7 @@ class Script(WMLResource):
 
         .. code-block:: python
 
-            script_revision = client.scripts.create_revision(script_uid)
+            script_revision = client.script.create_revision(script_uid)
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
         # We need to enable this once we add functionality for WSD
@@ -859,19 +875,24 @@ class Script(WMLResource):
 
             return final_response
 
-    def list_revisions(self, script_uid, limit=None):
+    def list_revisions(self, script_uid, limit=None, return_as_df=True):
         """Print all revisions for the given script uid in a table format.
 
         :param script_uid: stored script ID
         :type script_uid: str
         :param limit: limit number of fetched records
         :type limit: int, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed revisions or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
         .. code-block:: python
 
-            client.scripts.list_revisions(script_uid)
+            client.script.list_revisions(script_uid)
         """
         # We need to enable this once we add functionality for WSD
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
@@ -896,7 +917,9 @@ class Script(WMLResource):
              m[u'metadata'][u'commit_info'][u'committed_at']) for m in
             script_resources]
 
-        self._list(script_values, [u'GUID', u'REVISION_ID', u'NAME', u'REVISION_COMMIT'], limit, _DEFAULT_LIST_LENGTH)
+        table = self._list(script_values, [u'GUID', u'REVISION_ID', u'NAME', u'REVISION_COMMIT'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     def get_revision_details(self, script_uid, rev_uid=None):
         """Get metadata of script revision.
@@ -913,7 +936,7 @@ class Script(WMLResource):
 
         .. code-block:: python
 
-            script_details = client.scripts.get_revision_details(script_uid, rev_uid)
+            script_details = client.script.get_revision_details(script_uid, rev_uid)
         """
         # We need to enable this once we add functionality for WSD
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
