@@ -116,7 +116,7 @@ class Shiny(WMLResource):
         if shiny_meta.get('software_spec_uid'):
             shiny_sw_spec_id = shiny_meta[u'software_spec_uid']
 
-        if self._client.ICP_46:
+        if self._client.ICP_46 or self._client.ICP_47:
             shiny_sw_specs = ('rstudio_r4.2',)
             deprecated_shiny_sw_specs = ('shiny-r3.6',)
         else:
@@ -165,7 +165,7 @@ class Shiny(WMLResource):
                      }
                  }
             }
-            if self._client.ICP_46 and shiny_sw_spec_id:
+            if (self._client.ICP_46 or self._client.ICP_47) and shiny_sw_spec_id:
                 asset_meta['entity']['shiny_asset']['software_spec'] = \
                     {"base_id": shiny_sw_spec_id}
 
@@ -251,18 +251,28 @@ class Shiny(WMLResource):
 
 
                     #Step3: Put content to attachment
-                    with open(file_path, 'rb') as f:
-                        if not self._ICP:
-                            put_response = requests.put(
-                                attachment_url,
-                                data=f.read(),
-                                # files = f
-                            )
-                        else:
-                            put_response = requests.put(
-                                self._wml_credentials['url'] + attachment_url,
-                                files={'file': (name, f, 'application/octet-stream')}
-                            )
+                    try:
+                        with open(file_path, 'rb') as f:
+                            if not self._ICP:
+                                put_response = requests.put(
+                                    attachment_url,
+                                    data=f.read(),
+                                    # files = f
+                                )
+                            else:
+                                put_response = requests.put(
+                                    self._wml_credentials['url'] + attachment_url,
+                                    files={'file': (name, f, 'application/octet-stream')}
+                                )
+                    except Exception as e:
+                        deletion_response = requests.delete(
+                            self._client.service_instance._href_definitions.get_data_asset_href(asset_id),
+                            params=self._client._params(),
+                            headers=self._client._get_headers()
+                        )
+                        print(deletion_response.status_code)
+                        raise WMLClientError("Failed while reading a file", e)
+
                     if put_response.status_code == 201 or put_response.status_code == 200:
                         # Step4: Complete attachment
                         complete_response = requests.post(
@@ -287,12 +297,17 @@ class Shiny(WMLResource):
             else:
                 raise WMLClientError("Failed while creating a shiny asset. Try again.")
 
-    def list(self, limit=None):
+    def list(self, limit=None, return_as_df=True):
         """Print stored shiny assets in a table format. If limit is set to None
         there will be only first 50 records shown.
 
         :param limit: limit number of fetched records
         :type limit: int, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed shiny assets or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
@@ -318,7 +333,9 @@ class Shiny(WMLResource):
             (m[u'metadata'][u'name'], m[u'metadata'][u'asset_type'], m["metadata"]["asset_id"]) for
             m in shiny_details]
 
-        self._list(space_values, [u'NAME', u'ASSET_TYPE', u'ASSET_ID'], None, _DEFAULT_LIST_LENGTH)
+        table = self._list(space_values, [u'NAME', u'ASSET_TYPE', u'ASSET_ID'], None, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     def download(self, shiny_uid, filename, rev_uid=None):
         """Download the content of a shiny asset.
@@ -688,16 +705,18 @@ class Shiny(WMLResource):
 
             return final_response
 
-    def list_revisions(self, shiny_uid, limit=None):
+    def list_revisions(self, shiny_uid, limit=None, return_as_df=True):
         """Print all revisions for the given shiny asset uid in a table format.
 
         :param shiny_uid: stored shiny asset ID
         :type shiny_uid: str
         :param limit: limit number of fetched records
         :type limit: int, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
 
-        :return: stored shiny revisions details
-        :rtype: table
+        :return: pandas.DataFrame with listed shiny revisions or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
@@ -728,7 +747,9 @@ class Shiny(WMLResource):
              m[u'metadata'][u'commit_info'][u'committed_at']) for m in
             shiny_resources]
 
-        self._list(shiny_values, [u'GUID', u'REVISION_ID', u'NAME', u'REVISION_COMMIT'], limit, _DEFAULT_LIST_LENGTH)
+        table = self._list(shiny_values, [u'GUID', u'REVISION_ID', u'NAME', u'REVISION_COMMIT'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     def get_revision_details(self, shiny_uid=None, rev_uid=None):
         """Get metadata of `shiny_uid` revision.
