@@ -178,11 +178,16 @@ class Spaces(WMLResource):
             return self._get_no_space_artifact_details(href+"?include=name,tags,custom,description", None, limit, 'spaces')
         return self._get_no_space_artifact_details(href, space_uid, limit, 'spaces')
 
-    def list(self, limit=None):
+    def list(self, limit=None, return_as_df=True):
         """Print stored spaces in a table format. If limit is set to None there will be only first 50 records shown.
 
         :param limit: limit number of fetched records
         :type limit: int, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed spaces or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
@@ -194,7 +199,9 @@ class Spaces(WMLResource):
         space_resources = self.get_details(limit=limit)[u'resources']
         space_values = [(m[u'metadata'][u'guid'], m[u'entity'][u'name'], m[u'metadata'][u'created_at']) for m in space_resources]
 
-        self._list(space_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+        table = self._list(space_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     def update(self, space_uid, changes):
         """Updates existing space metadata.
@@ -389,7 +396,7 @@ class Spaces(WMLResource):
 
         return members_details
 
-    def list_members(self, space_uid, limit=None):
+    def list_members(self, space_uid, limit=None, return_as_df=True):
         """Print stored members of a space in a table format.
         If limit is set to None there will be only first 50 records shown.
 
@@ -397,6 +404,11 @@ class Spaces(WMLResource):
         :type space_uid: str
         :param limit: limit number of fetched records
         :type limit: int, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed members or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
@@ -408,7 +420,9 @@ class Spaces(WMLResource):
         member_resources = self.get_members_details(space_uid,limit=limit)[u'resources']
         space_values = [(m[u'metadata'][u'guid'],  m[u'entity'][u'identity'], m[u'entity'][u'identity_type'], m[u'entity'][u'role'], m[u'metadata'][u'created_at']) for m in member_resources]
 
-        self._list(space_values, [u'GUID', u'USERNAME', u'IDENTITY_TYPE', u'ROLE', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+        table = self._list(space_values, [u'GUID', u'USERNAME', u'IDENTITY_TYPE', u'ROLE', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
+        if return_as_df:
+            return table
 
     @staticmethod
     def get_member_href(member_details):
