@@ -169,11 +169,16 @@ class SwSpec(WMLResource):
 
         return sw_spec_details
 
-    def list(self, limit=None):
+    def list(self, limit=None, return_as_df=True):
         """Print software specifications in a table format.
 
         :param limit: limit number of fetched records
         :type limit: int, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed software specifications or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
 
         **Example**
 
@@ -204,7 +209,9 @@ class SwSpec(WMLResource):
                  spec_state_dict.get(m['metadata']['asset_id'], {}).get('replacement', '')) for
                 m in asset_details]
 
-            self._list(sw_spec_values, ['NAME', 'ID', 'TYPE', 'STATE', 'REPLACEMENT'], limit, _DEFAULT_LIST_LENGTH)
+            table = self._list(sw_spec_values, ['NAME', 'ID', 'TYPE', 'STATE', 'REPLACEMENT'], limit, _DEFAULT_LIST_LENGTH)
+            if return_as_df:
+                return table
         else:
             from tabulate import tabulate
             header = ['NAME', 'ID', 'TYPE']
