@@ -136,7 +136,7 @@ class Training(WMLResource):
             details = self._get_artifact_details(url, training_uid, limit, 'trained models')
 
             if not _internal and details.get('entity', {}).get('status', {}).get('feature_engineering_components', {}).get('obm'):
-                if self._client.ICP_46:
+                if self._client.ICP_46 or self._client.ICP_47:
                     raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cpd"))
                 elif self._client.ICP:
                     print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
@@ -534,7 +534,7 @@ class Training(WMLResource):
             self._logger.debug(u'Response({}): {}'.format(state, run_details))
             return self.get_details(trained_model_guid, _internal=True)
 
-    def list(self, limit=None, asynchronous=False, get_all=False):
+    def list(self, limit=None, asynchronous=False, get_all=False, return_as_df=True):
         """Print stored trainings in a table format. If limit is set to None there will be only first 50 records shown.
 
         :param limit: limit number of fetched records at once
@@ -543,6 +543,8 @@ class Training(WMLResource):
         :type asynchronous: bool, optional
         :param get_all: if `True`, it will get all entries in 'limited' chunks
         :type get_all: bool, optional
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object when asynchronous is False, default: True
+        :type return_as_df: bool, optional
 
         **Examples**
 
@@ -571,7 +573,9 @@ class Training(WMLResource):
 
         else:
             details = self.get_details(limit=limit, get_all=get_all, _internal=True)
-            return preprocess_details(details)
+            table = preprocess_details(details)
+            if return_as_df:
+                return table
 
     def list_subtrainings(self, training_uid):
         """Print the sub-trainings in a table format.
