@@ -71,25 +71,25 @@ class Volume(WMLResource):
         .. code-block:: python
 
             metadata = {
-                client.volumes.ConfigurationMetaNamess.NAME: 'volume-for-wml-test',
+                client.volumes.ConfigurationMetaNames.NAME: 'volume-for-wml-test',
                 client.volumes.ConfigurationMetaNames.NAMESPACE: 'wmldev2',
                 client.volumes.ConfigurationMetaNames.STORAGE_CLASS: 'nfs-client'
                 client.volumes.ConfigurationMetaNames.STORAGE_SIZE: "2G"
             }
 
-            asset_details = client.scripts.store(meta_props=metadata)
+            asset_details = client.volumes.store(meta_props=metadata)
 
         Provision an existing PVC volume:
 
         .. code-block:: python
 
             metadata = {
-                client.volumes.ConfigurationMetaNamess.NAME: 'volume-for-wml-test',
+                client.volumes.ConfigurationMetaNames.NAME: 'volume-for-wml-test',
                 client.volumes.ConfigurationMetaNames.NAMESPACE: 'wmldev2',
                 client.volumes.ConfigurationMetaNames.EXISTING_PVC_NAME: 'volume-for-wml-test'
             }
 
-            asset_details = client.scripts.store(meta_props=metadata)
+            asset_details = client.volumes.store(meta_props=metadata)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -191,7 +191,7 @@ class Volume(WMLResource):
         if not self._client.ICP_PLATFORM_SPACES and not self._client.CLOUD_PLATFORM_SPACES:
             raise WMLClientError("Volume APIs are not supported. It is supported only for CP4D 3.5")
 
-        if (self._client.ICP_45 or self._client.ICP_46) and '::' not in name:
+        if (self._client.ICP_45 or self._client.ICP_46 or self._client.ICP_47) and '::' not in name:
             raise WMLClientError('Invalid name to start volume. Correct volume name format: `<namespace>::<name>`. Retrieve the correct name using `client.volumes.get_name(client.volumes.get_details(volume_id))` command.')
 
         start_url = self._client.service_instance._href_definitions.volume_service_href(name)
@@ -262,9 +262,15 @@ class Volume(WMLResource):
             print("Failed to upload the file to  volume. Try again.")
             return "FAILED"
 
-    def list(self):
+    def list(self, return_as_df=True):
         """Print stored volumes in a table format. If limit is set to None there will be only first 50 records shown.
 
+        :param return_as_df: determinate if table should be returned as pandas.DataFrame object, default: True
+        :type return_as_df: bool, optional
+
+        :return: pandas.DataFrame with listed volumes or None if return_as_df is False
+        :rtype: pandas.DataFrame or None
+
         **Example**
 
         .. code-block:: python
@@ -285,7 +291,11 @@ class Volume(WMLResource):
              m[u'id'],
              m['provision_status']) for m in asset_list]
 
-        self._list(volume_values, [u'NAME', u'ID', u'PROVISION_STATUS'], None, _DEFAULT_LIST_LENGTH)
+        table = self._list(volume_values, [u'NAME', u'ID', u'PROVISION_STATUS'], None, _DEFAULT_LIST_LENGTH)
+
+        if return_as_df:
+            return  table
+
 
     @staticmethod
     def get_id(volume_details):
