@@ -26,6 +26,7 @@ __all__ = [
     "DataStreamError",
     "WrongLocationProperty",
     "WrongFileLocation",
+    "EmptyDataSource",
     "SpaceIDandProjectIDCannotBeNone"
 ]
 
@@ -173,6 +174,10 @@ class WrongFileLocation(WMLClientError, ValueError):
     def __init__(self, reason):
         WMLClientError.__init__(self, "Cannot fetch data via Flight Service. Try again.", reason)
 
+class EmptyDataSource(WMLClientError, ValueError):
+    def __init__(self ):
+        WMLClientError.__init__(self, "Cannot fetch data via Flight Service. "
+                                      "Verify if data were saved under data connection and try again.")
 
 class SpaceIDandProjectIDCannotBeNone(WMLClientError, ValueError):
     def __init__(self, reason: str):
