@@ -180,7 +180,7 @@ class WMLResource:
             raise WMLClientError("The LIB_UID provided is not a valid model_definition/library")
 
     def _get_artifact_details(self, base_url, uid, limit, resource_name, summary=None,
-                              pre_defined=None, query_params=None, _async=False, _all=False):
+                              pre_defined=None, query_params=None, _async=False, _all=False, _filter_func=None):
         op_name = 'getting {} details'.format(resource_name)
 
         if uid is None:
@@ -192,7 +192,8 @@ class WMLResource:
                 pre_defined=pre_defined,
                 query_params=query_params,
                 _async=_async,
-                _all=_all
+                _all=_all,
+                _filter_func=_filter_func
             )
         else:
             # if not is_uid(uid):
@@ -216,7 +217,8 @@ class WMLResource:
             return self._handle_response(200, op_name, response_get)
 
     def _get_with_or_without_limit(self, url, limit, op_name, summary, pre_defined, revision=None,
-                                   skip_space_project_chk=False, query_params=None, _async=False, _all=False):
+                                   skip_space_project_chk=False, query_params=None, _async=False, _all=False,
+                                   _filter_func=None):
         params = self._client._params(skip_space_project_chk)
         if query_params is not None:
             params.update(query_params)
@@ -249,7 +251,7 @@ class WMLResource:
 
         href = "/".join(url.split('/')[3:])
         url_2 = "/".join(url.split('/')[:3])
-        resource_generator = NextResourceGenerator(self._client, url_2, href, params, _all)
+        resource_generator = NextResourceGenerator(self._client, url_2, href, params, _all, _filter_func)
 
         if _async:
             return resource_generator
@@ -280,7 +282,7 @@ class WMLResource:
                     resources.extend(result.get('results'))
 
                 return {
-                    "resources": resources
+                    "resources": _filter_func(resources) if _filter_func else resources
                 }
 
     def _get_no_space_artifact_details(self, base_url, uid, limit, resource_name, summary=None,pre_defined=None):
@@ -766,3 +768,29 @@ class WMLResource:
         #               "It will be read-only mode starting Nov 20th, 2020. i.e, you won't be able to create or update new assets and deployment using this client. "
         #               "Use Python 3.7 instead. For details, see https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/pm_service_supported_frameworks.html")
 
+    def _get_and_cache_spec_ids_for_state(self, spec_state):
+        if spec_state in self._client._spec_ids_per_state:
+            return self._client._spec_ids_per_state[spec_state]
+
+        url = self._client.service_instance._href_definitions.get_software_specifications_list_href()
+
+        params = self._client._params()
+        params['state'] = spec_state.value
+
+        response_post = requests.get(url, params=params,
+                                     headers=self._client._get_headers())
+
+        res = self._handle_response(200, u'list software specifications', response_post)
+
+        spec_ids = [r['id'] for r in res['results']]
+
+        self._client._spec_ids_per_state[spec_state] = spec_ids
+
+        return spec_ids
+
+    @staticmethod
+    def _get_filter_func_by_spec_ids(spec_ids):
+        def filter_func(resources):
+            return [r for r in resources if r['entity'].get('software_spec', {}).get('id') in spec_ids]
+
+        return filter_func
\ No newline at end of file
